###########################################################
### Ch5 - Script 1 - Load Data
###########################################################

###########################################################
### Packages
###########################################################
library(here)
library(tidyverse)

library(GThomsonThesis)
library(ggtree)
library(ggpubr)
library(tidygraph)
library(ggraph)
library(ggsignif)
library(ggrepel)


# I also use the twidlr https://github.com/drsimonj/twidlr
# commit e026dc0cb607f7b260d8a2a28905670330d263d8

###########################################################
### Data
###########################################################

# Load tree data
NFYA_tree <- read.tree(here("Data/Alignments/NF-YA_tree.newick"))
NFYA_tree$node.label <- as.numeric(NFYA_tree$node.label)
NFYB_tree <- read.tree(here("Data/Alignments/NF-YB_tree.newick"))
NFYB_tree$node.label <- as.numeric(NFYB_tree$node.label)
NFYC_tree <- read.tree(here("Data/Alignments/NF-YC_tree.newick"))
NFYC_tree$node.label <- as.numeric(NFYC_tree$node.label)

FTIP1_tree <- read.tree(here("Data/Alignments/FTIP1_tree.newick"))
FTIP1_tree$tip.label <- stringr::str_extract(FTIP1_tree$tip.label, "(?<=\\|)(.*)(?=\\|)") 
FTIP1_tree$tip.label[is.na(FTIP1_tree$tip.label)] <- "AT5G06850 (FTIP1)"

# Load flowering time data
FTdata <- here("Data/Ch5_flowering_time.csv") %>% 
  read_csv() %>% 
  ftRename() 

At_FTdata <- here("Data/Ch5_Arabidopsis_flowering_time.csv") %>% 
  read_csv() %>% 
  ftRename(species = 'Arabidopsis') 

# Load gene expression data
gene_expr <- here("Data/Ch5_gene_expression.csv") %>%
  read_csv()

# Load internode data
internode <- here("Data/Ch5_internodes.csv") %>%
  read_csv() %>%
  inRename()

# Load Y2H scoring data
Y2H_scor <- here('Data/Ch5_Y2H_scoring.csv') %>% 
  read_csv()
