###########################################################
### Ch5 - Script 2 - MtE1 - Medtr2g058520
###########################################################

###########################################################
### Theme
###########################################################
theme_set(my_theme())

###########################################################
### Flowering time - Screening in VLD
###
###             NF_line      Wild-type (R108)
### NF16583     Q790         Q791
### NF20110     Q606         Q607
###########################################################

FTdata %>% 
  filter(sowing_number %in% c("P790", "P791", "Q606", "Q607")) %>% 
  mutate(group = if_else(sowing_date == '21/10/15', "NF16583", "NF20110"),
         mutant = factor(mutant, levels = c("Wild-type",
                                            "Homozygote",
                                            "Heterozygote",
                                            "Wild-type segregant"))) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.8) +
  scale_colour_manual(values = g_colours[c(8,3,9,10)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  facet_grid( ~ group) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 30)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 11)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position="right",#"none",
        axis.title.x = element_text(),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        plot.title = element_text(size = 14, face = "bold")) 

ggsave("Ch5_E1_screening.png", height = 103, width = 257, units = "mm")

###########################################################
### Flowering time 
###
###             NF_line      Wild-type (R108)
### NF16583
###      LD     Q022         Q023
###      SD     P936         P939
###      VLD    P880, P881   P883   
###      VSD    P935         P938
###
### NF20110
###      VLD    Q733         Q743
###            (Q741 as a NF16583 control)
###########################################################
# NF16583
NF16583_flowering_top <- FTdata %>% 
  filter(sowing_number %in% c("Q022", "Q023", "P936")) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  facet_grid( ~ conditions) +
  geom_jitter(data = filter(FTdata, sowing_number == "P939"), size = 2, alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 125)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 30)) +
  labs(x = "", y = "") +
  theme(legend.position="none",
        axis.title.x = element_blank(),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        plot.title = element_text(size = 14, face = "bold")) +
  ggtitle("NF16583")

NF16583_flowering_bottom <- FTdata %>% 
  filter(sowing_number %in% c("P880", "P881", "P883", "P935", 
                              "P938")) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  facet_grid( ~ conditions) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 125)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 30)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position="none",
        axis.title.x = element_text(size = 14),
        axis.title.y = element_text(size = 14),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"))

# NF16583 differences
FTdata %>% 
  filter(sowing_number %in% c("Q022", "Q023", "P936", "P939",
                              "P880", "P881", "P883", "P935", 
                              "P938")) %>% 
  
  flr_summary()

FTdata %>% 
  filter(sowing_number %in% c("Q022", "Q023", "P936", "P939",
                              "P880", "P881", "P883", "P935", 
                              "P938")) %>% 
  
  flr_summary(group=conditions)  %>% 
  select(genotype, conditions, days_to_flower_mean) %>% 
  spread(genotype, days_to_flower_mean) %>% 
  mutate(difference = NF16583-R108, percentDifferent = (NF16583/R108)-1)

# NF20110
NF20110_flowering <- FTdata %>% 
  filter(sowing_number %in% c("Q733", "Q741", "Q743")) %>%
  mutate(genotype = if_else(genotype == "R108", "Wild-type", genotype)) %>% 
  #slice(c(-19, -26)) %>% # Check
  ggplot(aes(days_to_flower, node_num, colour = genotype)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3,10,8)]) +
  facet_grid( ~ conditions) +
  stat_ellipse(size = 1, alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 45)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 15)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position="right",
        legend.text = element_text(size = 14),
        strip.text = element_text(hjust = -0.001),
        axis.title.x = element_text(size = 14),
        axis.title.y = element_text(size = 14),
        panel.spacing = unit(1.5, "lines"),
        plot.title = element_text(size = 14, face = "bold")) +
  ggtitle('NF20110')

# NF20110 differences
FTdata %>% 
  filter(sowing_number %in% c("Q733", "Q741", "Q743"))  %>%
  flr_summary()

ggpubr::ggarrange(NF16583_flowering_top, 
                  NF16583_flowering_bottom, 
                  ggpubr::ggarrange(NF20110_flowering, NULL,
                                    widths = c(4, 1)),
                  nrow = 3,
                  labels = c("A", "", "B"),
                  heights = c(1,1,1))

# ggsave("Ch5_E1_flowering.png", width = 140, height = 182, units = 'mm')

###########################################################
### NF16583 gene linkage
###
### NF16583 segregating   Q055, Q056, Q057, Q058
### NF16583 Homozygote    Q059
### Wild-type (R108)      Q060
###########################################################

labs <- c("Wild-type" = "Wild-type",
          "Homozygote_F0" = expression(Homozygote~(F[0])),
          "Homozygote" = "Homozygote",
          "Heterozygote" = "Heterozygote",
          "Wild-type segregant" = "Wild-type segregant"
  )

# Days to flowering
NF16583_linkage_days <- FTdata %>% 
  filter(sowing_number %in% c("Q055", "Q056", "Q057", 
                              "Q058", "Q059", "Q060")) %>% 
  flr_summary(group = mutant) %>%
  mutate(mutant = case_when(genotype == "NF16583" & mutant == "Homozygote" ~ "Homozygote_F0",
                             TRUE ~ mutant),
         
         mutant = factor(mutant, levels = c("Wild-type",
                                              "Homozygote_F0",
                                              "Homozygote",
                                              "Heterozygote",
                                              "Wild-type segregant"
                                              ))) %>% 
  ggplot(aes(x = mutant, 
             y = days_to_flower_mean, fill = mutant)) + 
  geom_col() +
  geom_errorbar(aes(ymin = days_to_flower_lower_ci, 
                    ymax = days_to_flower_upper_ci), 
                position=position_dodge(0.9), width = 0.2) +
  scale_y_continuous(expand=c(0,0), limits = c(0, 50)) +
  scale_x_discrete(labels = labs) +
  labs(x = "", y = "Mean days to flowering") +
  scale_fill_manual(values = g_colours[c(8,4,3,9,10)]) +
  theme(legend.position = "bottom",
        axis.title.y = element_text(size=14),
        axis.text = element_text(size=10),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        legend.text = element_text(size=12)) +
  guides(fill=guide_legend(nrow=3,byrow=FALSE))

# Nodes at flowering
NF16583_linkage_nodes <- FTdata %>% 
  filter(sowing_number %in% c("Q055", "Q056", "Q057", 
                              "Q058", "Q059", "Q060")) %>% 
  flr_summary(group = mutant) %>%
  mutate(mutant = case_when(genotype == "NF16583" & mutant == "Homozygote" ~ "Homozygote_F0",
                             TRUE ~ mutant),
         mutant = factor(mutant, levels = c("Wild-type",
                                              "Homozygote_F0",
                                              "Homozygote",
                                              "Heterozygote",
                                              "Wild-type segregant"))) %>% 
  ggplot(aes(x = mutant, 
             y = node_num_mean, fill = mutant)) + 
  geom_col() +
  geom_errorbar(aes(ymin = node_num_lower_ci, 
                    ymax = node_num_upper_ci), 
                position=position_dodge(0.9), width = 0.2) +
  scale_y_continuous(expand=c(0,0), limits = c(0, 12)) +
  scale_x_discrete(labels = labs) +
  labs(x = "", y = "Mean nodes at flowering") +
  scale_fill_manual(values = g_colours[c(8,4,3,9,10)]) +
  theme(legend.position = "none",
        axis.title.y = element_text(size=14),
        axis.text = element_text(size=10),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank())


NF16583_linkage <- FTdata %>% 
  filter(sowing_number %in% c("Q055", "Q056", "Q057",
                              "Q058", "Q059", "Q060")) %>%
  mutate(mutant = case_when(mutant == "Homozygote" & genotype == "NF16583" ~ "Homozygote_F0",
                            TRUE ~ mutant),
         mutant = factor(mutant, levels = c("Wild-type",
                                            "Homozygote_F0",
                                            "Homozygote",
                                            "Heterozygote",
                                            "Wild-type segregant"))) %>%
  ggplot(aes(days_to_flower, fill = mutant)) +
  geom_histogram(binwidth=1) +
  geom_vline(xintercept = 27) +
  facet_wrap(~mutant, nrow = 5, scales = 'free_y') +
  scale_x_continuous(limits=c(0,35)) +
  scale_y_continuous(expand=c(0,0)) +
  scale_fill_manual(values = g_colours[c(8,4,3,9,10)]) +
  theme(legend.position = "none",
        axis.title.x = element_text(size=14, margin = margin(t = 0, r = 0, b = 0, l = 0)),
        axis.title.y = element_text(size=14, vjust = -0.1),
        strip.text.x = element_text(size=14, hjust = -0.001)) +
  labs(x = "Days to flower", y = "Number of plants") 

ggpubr::ggarrange(
  ggarrange(NF16583_linkage_days,
            NF16583_linkage_nodes, 
            nrow = 2, heights = c(1, 0.75), 
            labels = c("A",  "B")),
  NF16583_linkage,
  ncol = 2, labels = c(" ", "C") 
)

# NF16583 flowering time linkage differences
FTdata %>% 
  filter(sowing_number %in% c("Q055", "Q056", "Q057", "Q058", "Q059", "Q060")) %>% 
  flr_summary(group = mutant)

# ggsave("Ch5_E1_linkage.pdf", width = 160, height = 182, units = 'mm')

# Test segregation of late flowering phenotype - Chi-square goodness-of-fit
FTdata %>% 
  filter(sowing_number %in% c("Q055", "Q056", "Q057", "Q058")) %>% 
  mutate(flowering_status_days = if_else(days_to_flower >27, "Late", "WT_like")) %>% 
  group_by(flowering_status_days) %>% 
  tally() %>% 
  slice(c(2,1)) %>% 
  mutate(expected =  c(0.75, 0.25)) %$%
  chisq.test(n, p = expected)  %>% 
  broom::tidy()

# Test segregation of mte1 insertion - Chi-square goodness-of-fit
FTdata %>% 
  filter(sowing_number %in% c("Q055", "Q056", "Q057", "Q058")) %>% 
  group_by(mutant) %>% 
  tally() %>% 
  slice(c(3,1,2)) %>% 
  mutate(expected =  c(0.25, 0.5, 0.25)) %$%
  chisq.test(n, p = expected) %>% 
  broom::tidy()

# Test co-segregation of mte1 insertion with late flowering
# - Chi-square test of independence
FTdata %>% 
  filter(sowing_number %in% c("Q055", "Q056", "Q057", "Q058")) %>% 
  mutate(flowering_status_days = if_else(days_to_flower >27, "Late", "WT_like"),
         homozygote = if_else(mutant == "Homozygote", TRUE, FALSE)) %>% 
  select(homozygote, flowering_status_days) %>% 
  table() %>% 
  chisq.test(simulate.p.value = TRUE)

###########################################################
### MtE1 gene expression
###
### Tissue data was done using cDNA generated by 
### Mau Jaudal
###
### Diurnal timecourse was done using cDNA generated 
### from leaves by Martin Balcerowicz
### 
### NF16583 samples
###      NF16583   R108
### LD   P980      P981          
### SD   P936      P939          
### VLD  P880      P883          
### VSD  P935      P938   
###########################################################

# Tissue
tissues <- structure(list(sample = c("Ape_12", "Ape_27", "Bud_86", "Cot_5", 
                                     "Flo_86", "LDLea_12", "LDLea_27", "Mon_12", 
                                     "Roo_12", "Roo_5", "SDLea", "Ste_40"), 
                          tissue = c("Apex (12 days)", "Apex (27 days)", "Buds (86 days)", 
                                     "Cotyledon\n(5 days)", "Flowers (86 days)", "Leaves (LD)\n(12 days)", 
                                     "Leaves (LD)\n(27 days)", "Monofoliate\n(12 days)", "Root (12 days)", 
                                     "Root (5 days)", "Leaf (SD)", "Stem (40 days)")), 
                     .Names = c("sample", "tissue"), 
                     row.names = c(NA, -12L), 
                     class = c("tbl_df", "tbl", "data.frame"))

# Tissues
E1_tissues <- gene_expr %>% 
  filter(date == '23/07/18', target %in% c("MtE1", "MtPP2A")) %>% 
  rt_summary() %>% 
  rt_test() %>% 
  left_join(tissues) %>%
  mutate(tissue = factor(tissue, levels = tissue[c(10,9,4,8,6,7,11,12,1,2,3,5)])) %>% 
  
  ggplot(aes(tissue, mean_expr, fill = tissue)) +
  geom_col(fill = g_colours[8]) +
  geom_errorbar(aes(ymin = mean_expr - se, ymax = mean_expr + se), width = 0.25) +
  scale_y_continuous(expand = c(0,0), limits = c(0, 1)) +
  labs(y = expression("Expression relative to"~italic("PP2A"))) +
  theme(legend.position = 'none',
        axis.text = element_text(size = 18),
        axis.text.x = element_text(size = 8, angle = 45, hjust = 1),
        axis.title.x = element_blank()) +
  ggtitle(expression(italic("MtE1")))

# Diurnal timecourse
Expression_timecourse_MtE1 <- gene_expr %>%
  filter(date == "03/05/16") %>% 
  rt_summary() %>% 
  rt_test() %>% 
  mutate(sample = as.numeric(sample)) %>% 
  ggplot(aes(x = sample, y = mean_expr, group = condition, colour = condition)) + 
  geom_line(colour = "black", size = 1.2) + 
  geom_errorbar(aes(ymin = mean_expr - se, ymax = mean_expr + se), width = 0.4, colour = "black") +
  geom_point(size = 3) + 
  scale_color_manual(values = g_colours[c(3,8)]) +
  labs(x = "ZT time", y = expression("Expression relative to"~italic("PP2A"))) +
  scale_y_continuous(expand=c(0,0), limits = c(0, 1)) +
  theme(axis.title.x = element_text(margin = margin(t = 10), size = 18),
        legend.position="none",
        axis.title.y = element_text(size = 14),
        axis.text = element_text(size=14, face = "bold")) +
  ggtitle(expression(italic("MtE1")))

E1_LoI <- c("P880", "P881", "P883", "P980", "P981",
            "P935", "P938", "P936", "P939")
E1_genes <- c("MtE1", "MtFTa1", "MtFTa2", "MtFTb1", "MtFTb2")

NF16583_plot <- function(gene){
  gene_expr %>%
    filter(sample %in% E1_LoI,
           target %in% c(gene, "MtPP2A")) %>%
    rt_summary() %>%
    rt_test() %>%
    mutate(genotype = case_when(genotype == "NF16583_E1_Homo" ~ "NF16583",
                                genotype == "Wild_type_R108" ~ "Wild-type"),
           genotype = fct_relevel(genotype, "Wild-type", "NF16583"),
           condition = fct_relevel(condition, "LD", "VLD", "SD", "VSD")) %>%
    ggplot(aes(genotype, mean_expr, fill = genotype)) +
    geom_bar(stat = "identity") +
    geom_errorbar(aes(ymin = mean_expr - se,
                      ymax = mean_expr + se),
                  width = 0.2) +
    facet_grid(. ~ condition, switch = "x") +
    scale_y_continuous(expand=c(0,0), limits = c(0, 1)) +
    scale_fill_manual(values =  g_colours[c(8,3)]) +
    labs(y = expression("Expression relative to"~italic("PP2A"))) +
    theme(legend.position = "none",
          legend.title = element_blank(),
          axis.title.x = element_blank(),
          axis.text.x = element_blank(),
          axis.ticks.x = element_blank(),
          strip.placement = "outside",
          plot.title = element_text(size = 16, face = "bold"),
          axis.title.y = element_blank(),
          axis.text.y = element_text(size=14, face = "bold"))
}

E1_plots <- E1_genes %>% 
  map(NF16583_plot)

E1_plots[[1]] <- E1_plots[[1]] + 
  ggtitle(expression(italic("MtE1")))
E1_plots[[2]] <- E1_plots[[2]] + 
  ggtitle(expression(italic("MtFTa1")))
E1_plots[[3]] <- E1_plots[[3]] + 
  ggtitle(expression(italic("MtFTa2")))
E1_plots[[4]] <- E1_plots[[4]] + 
  ggtitle(expression(italic("MtFTb1")))
E1_plots[[5]] <- E1_plots[[5]] + 
  ggtitle(expression(italic("MtFTb2")))

ggarrange(
  NULL, E1_tissues,
  ggarrange(
    Expression_timecourse_MtE1,
    E1_plots[[1]],
    E1_plots[[2]], E1_plots[[3]],
    E1_plots[[4]], E1_plots[[5]],
    ncol=2, nrow = 4,
    labels = LETTERS[2:9]
  ),
  labels = c("A", "B", " "), nrow = 3,
  heights = c(0.25, 0.3, 0.75)
)

ggsave("Ch5_E1_expression.pdf", width = 200, height = 300, units = 'mm')

# Ct summary tables
E1_labels <- c("P980" = "NF16583 LD",
               "P981" = "Wild-type LD",
               
               "P936" = "NF16583 SD",
               "P939" = "Wild-type SD",
               
               "P880" = "NF16583 VLD",
               "P883" = "Wild-type VLD",
               
               "P935" = "NF16583 VSD",
               "P938" = "Wild-type VSD")

# Tissues table
gene_expr %>% 
  filter(date == '23/07/18', target %in% c("MtE1", "MtPP2A")) %>% 
  left_join(tissues) %>%
  mutate(sample = tissue) %>% 
  select(-tissue) %>% 
  rt_calc() 

# Diurnal table
gene_expr %>%
  filter(date == "03/05/16") %>% 
  mutate(sample = paste(sample, condition)) %>% 
  rt_calc() %>% 
  separate(sample, c("sample", "condition"), " ") 

# NF16583 E1
gene_expr %>% 
  filter(sample %in% E1_LoI,
         target %in% c("MtE1", "MtPP2A")) %>% 
  mutate(genotype = case_when(genotype == "NF16583_E1_Homo" ~ "NF16583",
                              genotype == "Wild_type_R108" ~ "Wild-type")) %>% 
  rt_calc() %>% 
  left_join(enframe(E1_labels) %>%
    separate(value, c("genotype", "condition"), " ") %>% 
    rename(sample = name))

# NF16583 FTa1
gene_expr %>%
  filter(sample %in% E1_LoI,
         target %in% c("MtFTa1", "MtPP2A")) %>% 
  mutate(genotype = case_when(genotype == "NF16583_E1_Homo" ~ "NF16583",
                              genotype == "Wild_type_R108" ~ "Wild-type")) %>% 
  rt_calc() %>% 
  left_join(enframe(E1_labels) %>%
              separate(value, c("genotype", "condition"), " ") %>% 
              rename(sample = name))  

# NF16583 FTa2
gene_expr %>%
  filter(sample %in% E1_LoI,
         target %in% c("MtFTa2", "MtPP2A")) %>% 
  mutate(genotype = case_when(genotype == "NF16583_E1_Homo" ~ "NF16583",
                              genotype == "Wild_type_R108" ~ "Wild-type")) %>% 
  rt_calc() %>% 
  left_join(enframe(E1_labels) %>%
              separate(value, c("genotype", "condition"), " ") %>% 
              rename(sample = name)) 

# NF16583 FTb1
gene_expr %>%
  filter(sample %in% E1_LoI,
         target %in% c("MtFTb1", "MtPP2A")) %>% 
  mutate(genotype = case_when(genotype == "NF16583_E1_Homo" ~ "NF16583",
                              genotype == "Wild_type_R108" ~ "Wild-type")) %>% 
  rt_calc() %>% 
  left_join(enframe(E1_labels) %>%
              separate(value, c("genotype", "condition"), " ") %>% 
              rename(sample = name))

# NF16583 FTb2
gene_expr %>%
  filter(sample %in% E1_LoI,
         target %in% c("MtFTb2", "MtPP2A")) %>% 
  mutate(genotype = case_when(genotype == "NF16583_E1_Homo" ~ "NF16583",
                              genotype == "Wild_type_R108" ~ "Wild-type")) %>% 
  rt_calc() %>% 
  left_join(enframe(E1_labels) %>%
              separate(value, c("genotype", "condition"), " ") %>% 
              rename(sample = name)) 

###########################################################
### NF16583 transformation with 35S::MtE1 - T0
###
### Transformants (sowing number, callus, plantlets)
### Q190 #13 1,2,3,4,5
### Q190 #15 1,2,3,4,5
### Q190 #22 1
### Q190 #25 1,2
### Q190 #27 1,2
###
### Regeneration controls
### Q193 10 3
### Q190 22 1
###########################################################

# Expression

T0_x_labels <- c("Q190_13_1" = '#13-1',
              "Q190_15_1" = '#15-1',
              "Q190_22_1" = '#22-1',
              "Q190_25_1" = '#25-1',
              "Q190_27_1" = '#27-1', 
              "Q193_10_3" = '#10-3', 
              "Q193_12_1" = '#12-1')

T0_led_labels <- c("T0_NF16583_pB2GW7_E1_R108" = 'NF16583 Homozygous \n(35S::MtE1)',
                "R108_regen" = 'Regeneration control')

# MtE1 T0 expression
T0_expression <- gene_expr %>% 
  filter(grepl(c("Q19"), sample), target %in% c("MtE1", "MtPP2A")) %>% 
  rt_summary() %>% 
  rt_test() %>% 
  ggplot(aes(sample, mean_expr, fill = genotype)) +
  geom_bar(stat = 'identity', alpha = 0.9) +
  geom_errorbar(aes(ymin = mean_expr - se, 
                    ymax = mean_expr + se), 
                width = 0.2) +
  scale_y_continuous(expand=c(0,0), limits = c(0, 1)) +
  scale_x_discrete(labels = T0_x_labels) +
  scale_fill_manual(values = g_colours[c(8,9)], labels = T0_led_labels)  +
  labs(x = " ", y = expression("Expression relative to"~italic("PP2A"))) +
  # ggtitle(expression(italic("MtE1"))) +
  theme(legend.position = "none",
        legend.title=element_blank(),
        legend.text = element_text(size = 14),
        plot.title = element_text(size = 20, face = "bold"))

# MtE1 T0 expression summary
gene_expr %>% 
  filter(grepl(c("Q19"), sample), target %in% c("MtE1", "MtPP2A")) %>% 
  mutate(genotype = case_when(genotype == "NF16583_pB2GW7_E1_R108" ~ "NF16583 Mtfe 35S::MtE1",
                              genotype == "R108_regen" ~ "Regenerated wild-type")) %>% 
  rt_calc() 

# T0 flowering
supp_trans_flowering <- data_frame(
  days_to_flower = c(52.8, 66.1),
  node_num = c(16.1, 16.4),
  mutant = c('Wild-type', "NF16583 35S::MtE1"),
  plant_num = rep(NA, 2),
  label = NA)

T0_point_labels <- tibble(genotype = rep("NF16583_pB2GW7_E1_R108", 4),
                          plant_num = c("13-1", "13-3", "22-1", "27-1"), 
                          label = c("#13-1", "#13-3", "#22-1", "#27-1"))

T0_flowering <- FTdata %>% 
  filter(sowing_number %in% c("Q190", "Q193")) %>%
  mutate(mutant = if_else(mutant == 'Transformed', "NF16583 35S::MtE1", mutant)) %>% 
  left_join(T0_point_labels) %>% 
  ggplot(aes(days_to_flower, replace_na(node_num, 0.5), label = label, colour = mutant)) +
  geom_jitter(size = 4, alpha = 0.7) +
  scale_colour_manual(values = g_colours[c(9,8)]) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 80)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 30)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(0.325, 0.9),
        axis.title.x = element_text(size = 20),
        axis.title.y = element_text(size = 20),
        axis.text.x = element_text(size = 16),
        axis.text.y = element_text(size = 16),
        legend.text = element_text(size = 20)) +
  geom_point(data = supp_trans_flowering, shape = 3, size = 3, stroke = 2, alpha = 0.6) + 
  guides(colour = guide_legend(override.aes = list(shape = 22)))  +
  geom_label_repel(nudge_y  = 5,
                   nudge_x  = 1,
                   segment.size  = 0.6)



ggarrange(NULL, T0_expression, T0_flowering, labels = c("A","B","C"), 
          ncol=3, widths = c(1,1.25,1.25), font.label = list(size = 22))

# ggsave("Ch5_NF16583_35S_MtE1.png", units = "mm", width = 400, height = 129)

###########################################################
### NF16583 transformation with 35S::MtE1 - T1
###
### Progeny of #13-3
###                    LD     VLD
### NF16583            Q516   Q518
### NF16583 35S::MtE1  Q517   Q519
### Wild-type          Q520   Q521
###
### Progeny of #22-1
###                    LD     VLD
### NF16583            Q610   Q605
### NF16583 35S::MtE1  Q608   Q603
### Wild-type          Q611   Q607
###
### Progeny of #27-1
###                    LD     VLD
### NF16583            Q610   Q605
### NF16583 35S::MtE1  Q609   Q604
### Wild-type          Q611   Q607
###########################################################


# T1 flowering 
T1_trans_data <- FTdata %>% 
  filter(sowing_number %in% c(c(paste0("Q5", c(16:21)), paste0("Q60", 3:9), "Q610", "Q611"))) %>% 
  mutate(comments = case_when(sowing_number %in% paste0("Q5", c(16:21)) ~ "Progeny of #13-3",
                              sowing_number %in% c(paste0("Q60", c(3,5,7,8)), "Q610", "Q611") ~ "Progeny of #22-1",
                              TRUE ~ comments)) %>%
  bind_rows(FTdata %>%
              filter(sowing_number %in% c("Q605", "Q607", "Q610", "Q611")) %>%
              mutate(comments = "Progeny of #27-1")) %>% 
  mutate(mutant = case_when(mutant == 'Homozygote' ~ "NF16583",
                            mutant == 'Transformed' ~ "NF16583 35S::MtE1",
                            mutant == 'Wild-type' ~ "Wild-type (R108)",
                            TRUE ~ mutant)) 

T1_E1_trans_LD <- T1_trans_data %>% 
  filter(conditions == "LD") %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(4,9,8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  facet_grid(comments ~ .) + 
  scale_x_continuous(expand = c(0, 0), limits = c(0, 80)) + 
  scale_y_continuous(expand = c(0, 0), limits = c(0, 25)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(.5, .955),
        legend.text = element_text(size = 16),
        axis.title.x = element_text(vjust = -2),
        panel.spacing = unit(2, "lines"))

T1_E1_trans_VLD <- T1_trans_data %>% 
  filter(conditions == "VLD",
         !sowing_number %in% c("Q519","Q604")) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  # scale_colour_manual(values = g_colours[c(4,9,8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  facet_grid(comments ~ .) + 
  scale_x_continuous(expand = c(0, 0), limits = c(0, 45)) + 
  scale_y_continuous(expand = c(0, 0), limits = c(0, 20)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position="none",
        legend.text = element_text(size = 16),
        axis.title.x = element_text(vjust = -2),
        panel.spacing = unit(2, "lines")) +
  geom_jitter(data = filter(T1_trans_data, sowing_number %in% c("Q519","Q604")), size = 2, alpha = 0.6)

# Progeny of #13-3 expression
T1_E1_13_3_expression <- gene_expr %>% 
  filter(grepl('Q5', sample), 
         target %in% c('MtE1', 'MtPP2A')) %>% 
  rt_summary() %>% 
  rt_test() %>% 
  mutate(genotype = case_when(genotype == "Wild_type_R108" ~ "Wild-type (R108)",
                              genotype == "T1_NF16583_pB2GW7_E1_R108" ~ "NF16583 35S::MtE1",
                              genotype == "NF16583_E1_Homo" ~ "NF16583"),
         genotype = factor(genotype, levels = c("Wild-type (R108)", "NF16583", "NF16583 35S::MtE1"))
  ) %>%
  ggplot(aes(genotype, mean_expr, fill = genotype)) +
  geom_col() + 
  geom_errorbar(aes(ymin = mean_expr - se, 
                    ymax = mean_expr + se), 
                width = 0.2) +
  facet_grid(.~ condition, switch = "x") +
  scale_y_continuous(expand=c(0,0), limits = c(0, 1)) +
  scale_fill_manual(values =  g_colours[c(8,3,9)]) +
  labs(y = "Expression relative to PP2A") +
  ggtitle(expression(italic("MtE1")*" - Progeny of #13-3")) +
  theme(strip.placement = 'outside',
        strip.text = element_text(size = 25),
        axis.title.x = element_blank(),
        axis.title.y = element_text(size = 25),
        axis.text.x = element_blank(),
        axis.text.y = element_text(size = 25),
        axis.ticks.x = element_blank(),
        legend.position = c(0.6, 0.9),
        plot.title = element_text(size = 25, face = "bold"),
        legend.text=element_text(size=25))

ggarrange(
  ggarrange(T1_E1_trans_LD, T1_E1_trans_VLD, ncol=2, labels = c("A","B"), font.label = list(size = 18)),
  T1_E1_13_3_expression, nrow = 2, labels = c("", "C"), heights = c(3,1.5))

# ggsave('Ch5_T2-E1_trans.pdf', units = "mm", width = 190, height = 225)

# MtE1 T1 expression summary
gene_expr %>% 
  filter(grepl('Q5', sample), 
         target %in% c('MtE1', 'MtPP2A')) %>% 
  mutate(genotype = case_when(genotype == "Wild_type_R108" ~ "Wild-type (R108)",
                              genotype == "T1_NF16583_pB2GW7_E1_R108" ~ "NF16583 35S::MtE1",
                              genotype == "NF16583_E1_Homo" ~ "NF16583")) %>% 
  rt_calc() 

# T1 summary flowering -days to flowering
T1_trans_data %>% 
  group_by(comments) %>% 
  nest() %>%  
  mutate(data = map(data, ~  mutate(.x, comments = NA)  %>% 
                      select(sowing_number, conditions, genotype, individual, plant_num, 
                             sowing_date, flowering_date, days_to_flower, first_bud_loc, 
                             node_num, comments, mutant)), 
         summary = map(data, ~  flr_summary(.x, group = conditions) %>% 
                                select(genotype, conditions, days_to_flower_mean) %>% 
                                spread(genotype, days_to_flower_mean))) %>% 
  select(-data) %>% 
  unnest(summary)

### T1 size
batch_info <- data_frame(sowing_number = c("Q516", "Q517", "Q520", "Q608", "Q609", 
                                           "Q610", "Q611", "Q518", "Q519", "Q521", 
                                           "Q603", "Q604", "Q605", "Q607"),
                         batch = c(1, 1, 1, 2, 2, 2, 2, 
                                   3, 3, 3, 4, 4, 4, 4))

trans_internodes <- internode %>% 
  filter(sowing_number %in% c(c(paste0("Q5", c(16:21)), paste0("Q60", 3:9), "Q610", "Q611"))) %>% 
  left_join(batch_info)

trans_names <- data_frame(genotype = c('NF16583_Mte1_Homo', 'R108', 'NF16583_pB2GW7_E1_R108', 'NF16583_pB2GW7_E1_R108', 'NF16583_pB2GW7_E1_R108'),
                          comments = c(NA, NA, 'Progeny of #13-3', 'Progeny of #22-1', 'Progeny of #27-1'),
                          # name = c('NF16583', 'Wild-type \n(R108)', 'NF16583 \n35S::MtFE\n#13-3', 'NF16583 \n35S::MtFE\n#22-1', 'NF16583 \n35S::MtFE\n#27-1'))
                          name = c('NF16583', 'Wild-type \n(R108)', '#13-3', '#22-1', '#27-1'))

## T1 data
# Node number
trans_t1_nodenum <- trans_internodes %>%
  mutate(plant_id = paste(sowing_number, plant_number, sep = "_")) %>%
  select(plant_id, batch, conditions, genotype, comments, matches('N[0-9]')) %>% 
  gather(node, value, -batch, -conditions, -genotype, -comments, -plant_id) %>% 
  filter(!is.na(value)) %>% 
  group_by(batch, conditions, genotype, comments, plant_id) %>% 
  tally() %>% 
  left_join(trans_names) %>% 
  # mutate(name = factor(name, levels = c('NF16583', 'NF16583 \n35S::MtFE\n#13-3', 
  #                                       'NF16583 \n35S::MtFE\n#22-1', 'NF16583 \n35S::MtFE\n#27-1',
  #                                       'Wild-type \n(R108)') ))
  mutate(name = factor(name, levels = c('NF16583', '#13-3', 
                                      '#22-1', '#27-1',
                                      'Wild-type \n(R108)') ))

# Plant height/width
trans_t1_h_w <- trans_internodes %>% 
  left_join(trans_names) %>% 
  mutate(name = factor(name, levels = c('NF16583', '#13-3', 
                                        '#22-1', '#27-1',
                                        'Wild-type \n(R108)') ))

# Transgenics relative to R108
trans_t1_h_w  %>% 
  mutate(name = case_when(grepl("#", name) ~ paste0("trans", str_sub(name, 2, 3)),
                          grepl("R108", name) ~ "R108",
                          TRUE ~ as.character(name)
  )) %>% 
  group_by(batch, conditions, name) %>% 
  summarise(average = mean(plant_height)) %>% # or secondary_axis_length
  spread(name, average) %>% 
  mutate(homo_WT_diff = NF16583/R108,
         trans13_WT_diff = trans13/R108,
         trans22_WT_diff = trans22/R108,
         trans27_WT_diff = trans27/R108)

# Transgenics relative to mutant
trans_t1_h_w  %>% 
  mutate(name = case_when(grepl("#", name) ~ paste0("trans", str_sub(name, 2, 3)),
                          grepl("R108", name) ~ "R108",
                          TRUE ~ as.character(name)
  )) %>% 
  group_by(batch, conditions, name) %>% 
  summarise(average = mean(plant_height)) %>% # or secondary_axis_length
  spread(name, average) %>% 
  mutate(
         trans13_homo_diff = trans13/NF16583,
         trans22_homo_diff = trans22/NF16583,
         trans27_homo_diff = trans27/NF16583)

## T1 size graphs
# Node number
trans_t1_nodenum_graph <- trans_t1_nodenum %>% 
  ggplot(aes(name, n)) + 
  geom_boxplot(size=0.5, outlier.alpha = 0) + 
  geom_jitter(size=2, width = 0.1, aes(colour = genotype), alpha = 0.7) +
  facet_grid(cols = vars(batch), scales = "free_x") +
  scale_colour_manual(values = g_colours[c(4,9,8)],
                      labels = c('NF16583', 'Transformed', 'Wild-type (R108')) +
  geom_signif(comparisons = list(c('NF16583', 'Wild-type \n(R108)')),
              test = 't.test', y_position = 26) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 28)) +
  theme(legend.position = "none",
        strip.text = element_blank(),
        axis.title = element_text(size=20),
        axis.title.x = element_blank(),
        panel.spacing = unit(2, "lines")) +
  labs(y = "Node number", x = "")

# Plant height
trans_t1_height_graph <- trans_t1_h_w %>% 
  ggplot(aes(name, plant_height)) + 
  geom_boxplot(size=0.75, outlier.shape = NA) +
  geom_jitter(size=2, width = 0.1, aes(colour = genotype), alpha = 0.7) +
  facet_grid(cols = vars(batch), scales = "free_x") +
  scale_colour_manual(values = g_colours[c(4,9,8)],
                      labels = c('NF16583', 'Transformed', 'Wild-type')) +
  geom_signif(comparisons = list(c('NF16583', 'Wild-type \n(R108)')),
              test = 't.test', y_position = 34) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 35)) +
  theme(legend.position = "none",
        strip.text = element_blank(),
        axis.title = element_text(size=20),
        axis.title.x = element_blank(),
        panel.spacing = unit(2, "lines")) +
  labs(y = "Plant Height (cm)")

# Plant width
trans_t1_width_graph <- trans_t1_h_w %>% 
  ggplot(aes(name, secondary_axis_length)) + 
  geom_boxplot(size=0.75, outlier.shape = NA) +
  geom_jitter(size=2, width = 0.1, aes(colour = genotype), alpha = 0.7) +
  facet_grid(cols = vars(batch), scales = "free_x") +
  scale_colour_manual(values = g_colours[c(4,9,8)],
                      labels = c('NF16583', 'Transformed', 'Wild-type')) +
  
  geom_signif(comparisons = list(c('NF16583', 'Wild-type \n(R108)')),
              test = 't.test', y_position = 48) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 49)) +
  theme(legend.position = "none",
        strip.text = element_blank(),
        axis.text.x = element_text(size=14),
        axis.title = element_text(size=20),
        axis.title.x = element_blank(),
        panel.spacing = unit(2, "lines")) +
  labs(y = "Secondary axis length (cm)")

# Internodes
trans_internodes_graph <- trans_internodes %>%
  mutate(plant_id = paste(sowing_number, str_sub(comments, start= -4), plant_number, sep = "_")) %>% 
  select(plant_id, batch, conditions, genotype, comments, matches('N[0-9]')) %>% 
  gather(node, value, -plant_id, -conditions, -genotype, -comments, -batch) %>% 
  filter(!is.na(value)) %>% 
  mutate(node = str_remove(string = node, "N") %>% 
           as.numeric()) %>% 
  arrange(plant_id, node) %>% 
  mutate(internode = if_else(node == 0, 0, value - lag(value))) %>% 
  group_by(batch, conditions, comments, genotype, node) %>% 
  mutate(mean_internodes = mean(internode),
         node_num = n(),
         node_sd = sd(internode),
         moe = qt(0.95, node_num - 1) * (node_sd/sqrt(node_num))) %>% 
  left_join(trans_names) %>% 
  
  select(batch, genotype, name, node, mean_internodes, moe) %>% 
  distinct() %>% 
  
  ggplot(aes(mean_internodes, node,  group = name, colour = name)) +
  geom_path(size = 1.2) +
  geom_point() +
  geom_errorbarh(aes(xmin = mean_internodes - moe, xmax = mean_internodes + moe), 
                 height = 0.5) +
  facet_grid(cols = vars(batch), scales = "fixed", space = "fixed") +
  scale_colour_manual(values = c(g_colours[9], "#456e98", g_colours[c(5,4,8)]),
                      labels = c('#13-3', '#22-1', '#27-1','NF16583', 
                                 'Wild-type (R108)')) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 23)) +
  theme(legend.position =c(0.925, 0.8),
        legend.text = element_text(size = 16),
        # strip.text = element_text(hjust = 0, face="bold", size=14),
        strip.text = element_blank(),
        axis.title = element_text(size=20),
        panel.grid.major.x = element_line(),
        panel.grid.major.y = element_blank(),
        panel.spacing = unit(2, "lines")) +
  labs(x = "Internode length (cm)", y = "Internode")

ggarrange(NULL, trans_t1_nodenum_graph, trans_t1_height_graph, 
       trans_t2_width_graph, trans_internodes_graph,
       labels = LETTERS[1:5], nrow = 5,  font.label = list(size = 18))

# ggsave('Ch5_T2-E1_trans_size.png', units = "mm", width = 250, height = 450)

## T1 size FDR calc.
# Function to do it
FDR_ttests <- function(data, var){
  
  enq_var <- enquo(var)
  
  data %>% 
    mutate(name = case_when(grepl("#", name) ~ paste0("trans", str_sub(name, -4, -3)),
                            grepl("R108", name) ~ "R108",
                            TRUE ~ as.character(name)
    )) %>% 
    group_by(batch, name) %>% 
    mutate(count = 1:n()) %>% 
    group_by(batch) %>% 
    nest() %>% 
    arrange(batch) %>% 
    mutate(data = map(data, ~ select(.x, count, name, !!enq_var) %>% 
                        group_by(name) %>% 
                        spread(name, !!enq_var)),
           homo_WT = map_dbl(data, ~ t.test(.x$NF16583, .x$R108) %>% broom::tidy() %>% pull(p.value)),
           homo_trans13 = if_else(batch %in% c(1,3), map_dbl(data, ~ t.test(.x$NF16583, .x$trans13) %>% 
                                                               broom::tidy() %>% 
                                                               pull(p.value)), 
                                  NA_real_),
           homo_trans22 = if_else(batch %in% c(2,4), map_dbl(data, ~ t.test(.x$NF16583, .x$trans22) %>% 
                                                               broom::tidy() %>% 
                                                               pull(p.value)), 
                                  NA_real_),
           homo_trans27 = if_else(batch %in% c(2,4), map_dbl(data, ~ t.test(.x$NF16583, .x$trans27) %>% 
                                                               broom::tidy() %>% 
                                                               pull(p.value)), 
                                  NA_real_),
           
           WT_trans13 = if_else(batch %in% c(1,3), map_dbl(data, ~ t.test(.x$R108, .x$trans13) %>% 
                                                             broom::tidy() %>% 
                                                             pull(p.value)), 
                                NA_real_),
           WT_trans22 = if_else(batch %in% c(2,4), map_dbl(data, ~ t.test(.x$R108, .x$trans22) %>% 
                                                             broom::tidy() %>% 
                                                             pull(p.value)), 
                                NA_real_),
           WT_trans27 = if_else(batch %in% c(2,4), map_dbl(data, ~ t.test(.x$R108, .x$trans27) %>% 
                                                             broom::tidy() %>% 
                                                             pull(p.value)), 
                                NA_real_)) %>% 
    select(-data) %>% 
    gather(comparison, p_value, -batch) %>% 
    filter(!is.na(p_value)) %>% 
    arrange(comparison,batch) %>% # Account for the same controls
    mutate(adj_p_value = format(signif(p.adjust(p_value, method = 'fdr'), 2), scientific = TRUE))
}

# Node number - ignore warnings
trans_t1_nodenum %>% 
  FDR_ttests(n)
  
# Plant height
trans_t1_h_w %>% 
  select(batch, name, plant_height) %>% 
  FDR_ttests(plant_height)

# Plant width
trans_t1_h_w %>% 
  select(batch, name, secondary_axis_length) %>%
  FDR_ttests(secondary_axis_length)

