###########################################################
### Ch5 - Script 3 - MtFE - Medtr6g444980
###########################################################

###########################################################
### Theme
###########################################################
theme_set(my_theme())

###########################################################
### Flowering time 
###
### Absent/non-phenotype screening results
### NF5076      Q038         Q042
### NF8324      Q531         Q536 
### NF9701      Q039         Q042
### NF17758     Q532         Q536
### NF18291     Q534         Q536
### NF17742     Q533         Q536
###
###             NF_line      Wild-type (R108)
### NF5076
###      LD     Q515         Q520
###      SD     Q551, Q552   Q553  
###      VLD    Q420         Q427
###      VSD    Q537, Q538   Q539
###
###########################################################

## Absent/non-phenotype screening results
# Pop. sizes
FTdata %>% 
  filter(sowing_number %in% c("Q531", "Q038","Q039", "Q532", "Q534", "Q533",
                              "Q536", "Q042")) %>% 
  select(sowing_number, genotype, mutant) %>% 
  filter(genotype != "R108") %>% 
  group_by(genotype, mutant) %>% 
  tally() %>% 
  spread(mutant, n) %>% 
  mutate(total = sum(Heterozygote, Homozygote, `Wild-type segregant`, na.rm = TRUE))

# Plot
FTdata %>% 
  filter(sowing_number %in% c("Q531", "Q038","Q039", "Q532", "Q534", "Q533",
                              "Q536", "Q042")) %>%
  mutate(group = case_when(sowing_number %in% c("Q531", "Q536") ~ "NF8324",
                           sowing_number %in% c("Q038", "Q042") ~ "NF5076",
                           sowing_number == "Q039" ~ "NF9701",
                           sowing_number == "Q532" ~ "NF17758",
                           sowing_number == "Q534" ~ "NF18291",
                           sowing_number == "Q533" ~ "NF17742")) %>% 
  # Add R108 to group NF9701
  bind_rows(filter(., sowing_number == "Q042") %>% 
              mutate(group = "NF9701")) %>% 
  # Add R108 to group NF17758
  bind_rows(filter(., sowing_number == "Q536") %>% 
              mutate(group = "NF17758")) %>% 
  # Add R108 to group NF18291
  bind_rows(filter(., sowing_number == "Q536") %>%
              select(-group) %>%
              distinct() %>%
              mutate(group = "NF18291")) %>%
  # Add R108 to group NF17742
  bind_rows(filter(., sowing_number == "Q536") %>% 
              select(-group) %>% 
              distinct() %>%
              mutate(group = "NF17742")) %>% 
  mutate(group = factor(group, levels = c("NF8324", "NF5076", "NF9701",
                                          "NF17758", "NF18291", "NF17742")),
         mutant = factor(mutant, levels = c("Homozygote", "Heterozygote", 
                                            "Wild-type segregant", "Wild-type"))) %>%
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  
  scale_colour_manual(values = g_colours[c(3, 9, 10, 2)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  
  stat_ellipse(data = filter(FTdata, sowing_number == "Q536") %>% 
                 mutate(group = "NF18291", size = 2, alpha = 0.6), 
               size = 1, alpha = 0.6) +
  facet_wrap( ~ group, nrow = 2) +
  
  scale_x_continuous(expand = c(0, 0), limits = c(0, 40)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 15)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(.125, 0.35),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        axis.title.x = element_text(vjust = -2))

ggsave("Ch5_Otherlines_FE_flowering.png", width = 282, height = 168, units = 'mm')

# Flowerring time
NF5076_flowering_top <- FTdata %>% 
  filter(sowing_number %in% c("Q515", "Q520", "Q551", "Q552", "Q553")) %>% 
  mutate(genotype = if_else(genotype == "R108", "Wild-type", genotype)) %>% 
  ggplot(aes(days_to_flower, node_num, colour = genotype)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  facet_grid( ~ conditions) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 125)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 30)) +
  labs(x = "", y = "Nodes at flowering") +
  theme(legend.position=c(0.08, 0.85),
        legend.text = element_text(size = 14),
        axis.title.x = element_blank(),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"))

NF5076_flowering_bottom <- FTdata %>% 
  filter(sowing_number %in% c("Q420", "Q427", "Q537", "Q538", "Q539")) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  facet_grid( ~ conditions) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 125)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 30)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position="none",
        # axis.title.x = element_blank(),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"))

# NF5076 differences
FTdata %>% 
  filter(sowing_number %in% c("Q515", "Q520", "Q551", "Q552", "Q553", 
                              "Q420", "Q427", "Q537", "Q538", "Q539")) %>% 
  flr_summary(group = conditions) 

FTdata %>% 
  filter(sowing_number %in% c("Q515", "Q520", "Q551", "Q552", "Q553", 
                              "Q420", "Q427", "Q537", "Q538", "Q539")) %>% 
  flr_summary(group = conditions) %>% 
  select(genotype, conditions, days_to_flower_mean) %>% 
  spread(genotype, days_to_flower_mean) %>% 
  mutate(difference = NF5076-R108, percentDifferent = (NF5076/R108)-1)

# NF5076 x NF18291 cross
FE_cross_plot <- FTdata %>% 
  filter(sowing_number %in% c("Q798", "Q799", "Q800")) %>% 
  mutate(mutant = if_else(mutant == "Homozygote", 'NF5076 homozygote', mutant)) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.8) +
  scale_colour_manual(values = g_colours[c(10, 3, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 50)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 15)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(0.28, 0.775),
        axis.text.x = element_text(size = 12),
        axis.text.y = element_text(size = 12),
        axis.title.x = element_text(size=14),
        axis.title.y = element_text(size=14),
        legend.key.size = unit(1, 'lines')
        )

ggarrange(NULL,
          ggarrange(NULL, FE_cross_plot, ncol = 2, 
                    labels = c("B", ""), widths = c(1, 0.75)),
          nrow = 2, ncol = 1, labels = c("A", "B"))
# ggsave("Ch5_FEcross2.png", width = 217, height = 111, units = "mm")

# ggsave("Ch5_FEcross.pdf", width = 217, height = 111, units = "mm")

###########################################################
### NF5076 wild-type segregant size variation
###
###         tall  short  R108
### NF5076  Q586  Q587   Q597
###########################################################
T_S_heights <- internode %>% 
  filter(sowing_number %in% c("Q586", "Q587", "Q597")) %>% 
  mutate(comments = case_when(grepl("short", comments) ~ "WT Seg. \n(short)",
                              grepl("tall", comments) ~ "WT Seg. \n(tall)",
                              TRUE ~ "Wild-type"),
         comments = fct_relevel(comments, "WT Seg. \n(tall)", after = 1)) %>%
  ggplot(aes(comments, plant_height)) +
  geom_boxplot(size = 0.8, outlier.shape = NA) +
  geom_jitter(size=1.25, width = 0.1, 
              aes(colour = comments), alpha = 0.7) +
  scale_colour_manual(values = g_colours[c(8, 1, 3)]) +
  scale_y_continuous(expand=c(0,0), limits = c(0, 25)) +
  labs(x = "", y = "Plant height (cm)") +
  theme(legend.position = "none",
        axis.text = element_text(size = 10),
        axis.title.y = element_text(size = 12))

internode %>% 
  filter(sowing_number %in% c("Q586", "Q587", "Q597")) %>%
  select(sowing_number, plant_height, plant_number) %>% 
  twidlr::aov(plant_height ~ sowing_number) %>% #summary()
  TukeyHSD() %>% 
  broom::tidy() %>% 
  # mutate_if(is.numeric, abs) %>% 
  ggplot(aes(comparison, estimate)) +
  geom_hline(yintercept = 0) +
  geom_errorbar(aes(ymin=conf.low, ymax = conf.high)) +
  geom_point() 
    
T_S_flowering <- FTdata %>% 
  filter(sowing_number %in% c("Q586", "Q587", "Q597")) %>% 
  mutate(comments = case_when(grepl("short", comments) ~ "WT Seg. (short)",
                              grepl("tall", comments) ~ "WT Seg. (tall)",
                              TRUE ~ "Wild-type"),
         comments = fct_relevel(comments, "WT Seg. (tall)", after = 1)) %>%
  ggplot(aes(days_to_flower, node_num, colour = comments)) +
  geom_jitter(size = 1, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(8, 1, 3)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  scale_x_continuous(expand=c(0,0), limits = c(0, 35)) +
  scale_y_continuous(expand=c(0,0), limits = c(0, 10)) +
  labs(x = "Days to flowering", y = 'Nodes at flowering') +
  theme(legend.position=c(0.25, 0.875),
        legend.text = element_text(size = 10),
        axis.text = element_text(size = 10),
        axis.title.y = element_text(size = 12),
        axis.title.x = element_text(size = 12),
        legend.key.size = unit(0.5, 'lines'))

ggpubr::ggarrange(NF5076_flowering_top, 
                  NF5076_flowering_bottom, 
                  ggarrange(NULL, NULL, labels = c("B", "C")),
                  ggarrange(T_S_heights, T_S_flowering, 
                            align = "h", nrow=1, ncol=3 ,
                            widths = c(0.6,0.6, 0.4),
                            labels = c("D", "E", " ")),
                  NULL,
                  nrow = 5, ncol = 1,
                  labels = c("A", " ", " ", " ", "G"),
                  heights = c(1.2,1.2,1,1.4,1))


# ggsave("Ch5_NF5076_FE_flowering.pdf", width = 240, height = 297, units = 'mm')

###########################################################
### NF5076 gene linkage - flowering
###
### F2 generation
### NF5076            Q756, Q757       
### Wild-type (R108)  Q758
###
### F3 generation
### NF5076 (homo)     Q908, Q909 
###                   Q910, Q911 
### NF5076(WT seg)    Q912, Q913 
###                   Q915, Q916
###                   Q917
### NF5076 (homo F0)  Q918
### Wild-type (R108)  Q919
###########################################################

# F2 generation
NF5076_linkage_days <- FTdata %>% 
  filter(sowing_number %in% c("Q756", "Q757", "Q758")) %>% 
  flr_summary(group = mutant) %>%
  mutate(mutant = factor(mutant, levels = c("Wild-type",
                                     "Homozygote",
                                     "Heterozygote",
                                     "Wild-type segregant"))) %>% 
  ggplot(aes(x = mutant, 
             y = days_to_flower_mean, fill = mutant)) + 
  geom_col() +
  geom_errorbar(aes(ymin = days_to_flower_lower_ci, 
                    ymax = days_to_flower_upper_ci), 
                position=position_dodge(0.9), width = 0.2) +
  scale_y_continuous(expand=c(0,0), limits = c(0, 50)) +
  scale_x_discrete(labels = labs) +
  labs(x = "", y = "Mean days to flowering") +
  scale_fill_manual(values = g_colours[c(8,3,9,10)]) +
  theme(legend.position = "bottom",
        axis.title.y = element_text(size=14),
        axis.text = element_text(size=10),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        legend.text = element_text(size=12)) +
  guides(fill=guide_legend(nrow=2,byrow=FALSE))

NF5076_linkage_nodes <- FTdata %>% 
  filter(sowing_number %in% c("Q756", "Q757", "Q758")) %>% 
  flr_summary(group = mutant) %>%
  mutate(mutant = factor(mutant, levels = c("Wild-type",
                                            "Homozygote",
                                            "Heterozygote",
                                            "Wild-type segregant"))) %>% 
  ggplot(aes(x = mutant, 
             y = node_num_mean, fill = mutant)) + 
  geom_col() +
  geom_errorbar(aes(ymin = node_num_lower_ci, 
                    ymax = node_num_upper_ci), 
                position=position_dodge(0.9), width = 0.2) +
  scale_y_continuous(expand=c(0,0), limits = c(0, 12)) +
  scale_x_discrete(labels = labs) +
  labs(x = "", y = "Mean nodes at flowering") +
  scale_fill_manual(values = g_colours[c(8,3,9,10)]) +
  theme(legend.position = "none",
        axis.title.y = element_text(size=14),
        axis.text = element_text(size=10),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank())

NF5076_linkage <- FTdata %>% 
  filter(sowing_number %in% c("Q756", "Q757", "Q758")) %>% 
  mutate(mutant = factor(mutant, levels = c("Wild-type",
                                            "Homozygote",
                                            "Heterozygote",
                                            "Wild-type segregant"))) %>%
  ggplot(aes(days_to_flower, fill = mutant)) +
  geom_histogram(binwidth=1) +
  geom_vline(xintercept = 33) +
  facet_wrap(~mutant, nrow = 5, scales = 'free_y') +
  scale_x_continuous(limits=c(0,62)) +
  scale_y_continuous(expand=c(0,0)) +
  scale_fill_manual(values = g_colours[c(8,3,9,10)]) +
  theme(legend.position = "none",
        axis.title.x = element_text(size=14, margin = margin(t = 0, r = 0, b = 0, l = 0)),
        axis.title.y = element_text(size=14, vjust = -0.1),
        strip.text.x = element_text(size=14, hjust = -0.001)) +
  labs(x = "Days to flower", y = "Number of plants") 

# F3 generation
NF5076_linkage_days_F3 <- FTdata %>% 
  filter(grepl('Q9', sowing_number)) %>%
  mutate(mutant = if_else(sowing_number == 'Q918', "F0_homozygote", mutant) ) %>% 
  ggplot(aes(days_to_flower, fill = mutant)) +
  geom_histogram(position =  position_dodge(preserve = "single")) +
  labs(x = "Days to flower", y = "Number of plants") +
  scale_x_continuous(expand=c(0,0), limits=c(0,48)) +
  scale_y_continuous(expand=c(0,0), limits = c(0,10)) +
  scale_fill_manual(values = g_colours[c(4, 3, 8, 10)]) +
  theme(legend.position = 'none', 
        axis.text = element_text(size = 10),
        axis.title.x = element_text(size = 14),
        axis.title.y = element_text(size = 14))

ggarrange(
  ggarrange(
    ggarrange(NF5076_linkage_days,
              NF5076_linkage_nodes, 
              nrow = 2, heights = c(1, 0.75), 
              labels = c("A",  "B")),
    NF5076_linkage,
    ncol = 2, labels = c(" ", "C") 
  ),
  NF5076_linkage_days_F3,
  nrow = 2, heights = c(3,1)
)

# ggsave("Ch5_FE_linkage.pdf", width = 160, height = 182, units = 'mm')

# NF5076 flowering difference
FTdata %>% 
  filter(sowing_number %in% c("Q756", "Q757", "Q758")) %>% 
  flr_summary(group = mutant)

# Test segregation of late flowering phenotype - Chi-square goodness-of-fit
FTdata %>% 
  filter(sowing_number %in% c("Q756", "Q757")) %>% 
  mutate(flowering_status_days = if_else(days_to_flower >33, "Late", "WT_like")) %>% 
  group_by(flowering_status_days) %>% 
  tally() %>% 
  slice(c(2,1)) %>% 
  mutate(expected =  c(0.75, 0.25)) %$%
  chisq.test(n, p = expected)  %>% 
  broom::tidy()

# Test segregation of mtfe insertion - Chi-square goodness-of-fit
FTdata %>% 
  filter(sowing_number %in% c("Q756", "Q757")) %>% 
  group_by(mutant) %>% 
  tally() %>% 
  slice(c(3,1,2)) %>% 
  mutate(expected =  c(0.25, 0.5, 0.25)) %$%
  chisq.test(n, p = expected) %>% 
  broom::tidy()

# Test co-segregation of Mte1 insertion with late flowering
# - Chi-square test of independence
FTdata %>% 
  filter(sowing_number %in% c("Q756", "Q757")) %>% 
  mutate(flowering_status_days= if_else(days_to_flower > 33, "Late", "WT_like"),
         homozygote = if_else(mutant == "Homozygote", TRUE, FALSE))%>% 
  select(homozygote, flowering_status_days) %>% 
  table() %>% 
  chisq.test() %>% 
  broom::tidy()

###########################################################
### NF5076 gene linkage - size
###
### NF5076            Q756, Q757       
### Wild-type (R108)  Q758
###########################################################

# Identify unexpected phenotypes
unex_ph <- FTdata %>% 
  filter(sowing_number %in% c("Q756", "Q757", "Q758"),
         mutant == "Wild-type segregant" & days_to_flower > 33 | 
         mutant == "Heterozygote" & days_to_flower > 33 |
         mutant ==  "Homozygote" & days_to_flower <= 33) %>% 
  select(sowing_number, plant_num) %>%
  unite(ID, sowing_number, plant_num) %>% 
  pull(ID)

# Change in mean heights
NF5076_linkage_heights <- internode %>% 
  filter(sowing_number %in% c("Q756", "Q757", "Q758")) %>% 
  unite(ID, sowing_number, plant_number) %>% 
  mutate(phenotype = ifelse(ID %in% unex_ph, "unexpected", "expected")) %>%
  mutate(age = round(age, digits = -1),
         age = case_when(age == 30 ~ 33,
                         age == 50 ~ 48,
                         age == 60 ~ 63))  %>%
  select(ID, mutant, age, plant_height, secondary_axis_length, phenotype) %>% 
  group_by(mutant, age, phenotype) %>% 
  summarise(mean_height = mean(plant_height), moe_height = moe(plant_height)) %>% 
  unite(ID, mutant, phenotype, remove = F) %>% 
  filter(!(age == 63 & mutant != 'Homozygote' & phenotype == 'expected')) %>% 
  
  ggplot(aes(age, mean_height, colour = mutant, group = ID)) + 
  geom_line(aes(linetype = phenotype),
            position = position_dodge(width = 3), size = 1.5) +
  geom_errorbar(aes(ymin = mean_height - moe_height,
                    ymax = mean_height + moe_height),
                position = position_dodge(width = 3),
                width = 4,
                size = 0.8) +
  geom_point(aes(shape = phenotype), 
             position = position_dodge(width = 3), 
             size = 6) +
  scale_x_continuous(limits = c(30,65), breaks = seq(30, 65, 5)) +
  scale_y_continuous(expand = c(0,0), limits = c(0,25)) +
  scale_colour_manual(values = g_colours[c(6, 3, 8, 2)]) +
  scale_shape_manual(values = c(20, 1), guide = FALSE) +
  scale_linetype_discrete(guide = FALSE) +
  labs(x = 'Age of plant (days)', y = "Mean plant height (cm)") +
  theme(axis.text = element_text(size = 18),
        axis.title.y = element_text(size = 20),
        axis.title.x = element_text(size = 20, vjust = -2),
        legend.position = 'none',
        legend.text = element_text(size = 18))

# Change in mean node num
NF5076_linkage_nodes2  <- internode %>% 
  filter(sowing_number %in% c("Q756", "Q757", "Q758")) %>% 
  unite(ID, sowing_number, plant_number) %>% 
  mutate(phenotype = ifelse(ID %in% unex_ph, "unexpected", "expected"),
         age = round(age, digits = -1),
         age = case_when(age == 30 ~ 33,
                         age == 50 ~ 48,
                         age == 60 ~ 63),
         # mutant = if_else(mutant == 'Wild-type segregant', 'Wild-type\nsegregant', mutant),
         mutant = factor(mutant, 
                         levels = c("Wild-type", "Homozygote", 
                                    "Heterozygote", "Wild-type segregant"))) %>% 
  select(ID, mutant, age, phenotype, starts_with('N')) %>% 
  gather(internode, size, -ID, -mutant, -age, -phenotype) %>% 
  filter(!is.na(size)) %>% 
  group_by(ID, age, mutant, phenotype) %>% 
  count() %>% 
  group_by(mutant, age, phenotype) %>% 
  summarise(mean_nodes = mean(n), moe_nodes = moe(n)) %>% 
  unite(ID, mutant, phenotype, remove = F) %>% 
  filter(!(age == 63 & mutant != 'Homozygote' & phenotype == 'expected')) %>% 
  ggplot(aes(age, mean_nodes, colour = mutant, group = ID)) + 
  geom_line(aes(linetype = phenotype), 
            position = position_dodge(width = 2), size = 1.5) +
  geom_errorbar(aes(ymin = mean_nodes - moe_nodes,
                    ymax = mean_nodes + moe_nodes),
                position = position_dodge(width = 3),
                width = 4,
                size = 0.8) +
  geom_point(aes(shape = phenotype), position = position_dodge(width = 3), 
             size = 6) +
  scale_x_continuous(limits = c(30,65), breaks = seq(30, 65, 5)) +
  scale_y_continuous(expand = c(0,0), limits = c(6,18)) +
  scale_colour_manual(values = g_colours[c(8, 3, 6, 2)]) +
  scale_shape_manual(values = c(20, 1), guide = FALSE) +
  scale_linetype_discrete(guide = FALSE) +
  labs(x = 'Age of plant (days)', y = "Mean number of nodes") +
  theme(axis.text = element_text(size = 18),
        axis.title.y = element_text(size = 20),
        axis.title.x = element_text(size = 20, vjust = -2),
        legend.position = c(0.25, 0.85),
        legend.text = element_text(size = 20))

ggarrange(
  ggarrange(NF5076_linkage_heights,
          NF5076_linkage_nodes2, labels = c('A', "B"),
          font.label = list(size = 25)), 
          NULL, 
          nrow = 2, labels = c("A", "C"),
          font.label = list(size = 25))

# ggsave('Ch5_NF5076_linkage_heights.pdf', height = 240, width = 350, units = 'mm')

# Summary table
internode %>% 
  filter(sowing_number %in% c("Q756", "Q757", "Q758")) %>% 
  unite(ID, sowing_number, plant_number) %>% 
  mutate(phenotype = ifelse(ID %in% unex_ph, "unexpected", "expected")) %>%
  mutate(age = round(age, digits = -1),
         age = case_when(age == 30 ~ 33,
                         age == 50 ~ 48,
                         age == 60 ~ 63))  %>%
  select(ID, mutant, age, plant_height, secondary_axis_length, phenotype) %>% 
  group_by(mutant, age, phenotype) %>% 
  summarise(mean_height = mean(plant_height), moe_height = moe(plant_height)) %>% 
  unite(ID, mutant, phenotype, remove = F) %>% 
  filter(!(age == 63 & mutant != 'Homozygote' & phenotype == 'expected')) %>% 
  
  filter(phenotype == "expected") %>% 
  group_by(age) %>%
  select(mutant, age, mean_height) %>% 
  spread(mutant, mean_height)

# 33 days - WT Segs
7.01/10.9*100 # 64.3%
# 33 days - Hets
7.32/10.9*100 # 67.1%
# 33 days - Homo
0.742/10.9*100 # 6.8%

# 48 days - Homo vs 33 days WT
3.19/10.9*100 # 29.3%
# 48 days - Homo vs 48 days WT Segs
3.19/18.6*100 # 17.2%
# 68 days - Homo vs 33 days WT
5.78/10.9*100 # 53%

# Contrast expected vs unexpected
internode %>% 
  filter(sowing_number %in% c("Q756", "Q757", "Q758")) %>% 
  unite(ID, sowing_number, plant_number) %>% 
  mutate(phenotype = ifelse(ID %in% unex_ph, "unexpected", "expected")) %>%
  mutate(age = round(age, digits = -1),
         age = case_when(age == 30 ~ 33,
                         age == 50 ~ 48,
                         age == 60 ~ 63))  %>%
  select(ID, mutant, age, plant_height, secondary_axis_length, phenotype) %>% 
  group_by(mutant, age, phenotype) %>% 
  summarise(mean_height = mean(plant_height), moe_height = moe(plant_height)) %>% 
  unite(ID, mutant, phenotype, remove = F) %>% 
  filter(!(age == 63 & mutant != 'Homozygote' & phenotype == 'expected')) %>% 
  
  # filter(phenotype == "expected") %>% 
  group_by(phenotype) %>%
  nest() %>% 
  pull(data) %>% 
  names()

# 33 days - Unex WT Seg, Het, Homo
1.9/10.9*100 # 17.4%
2.28/10.9*100 # 20.9%
3.1/10.9*100 # 28.4%

# 48 days - Unex WT Seg, Het, Homo vs 33 day WT 
11.2/10.9*100 # 60.2%
11.6/10.9*100 # 62.4%
12.6/10.9*100 # 67.7%

# 48 days - Unex WT Seg, Het, Homo vs 48 day WT seg
11.2/18.6*100 # 102.7%
11.6/18.6*100 # 106.4%
12.6/18.6*100 # 115.6%

###########################################################
### Arabidopsis fe-1 complementation and 
###             Ler-0 overexpression
###
### fe-1
### line_number T2_line T3_line
###           1 Q722    Q787       
###           2 Q874    Q939      
### 
### Ler-0
### line_number T2_line T3_line
###           1 Q723    Q786      
###           2 Q772    Q938      
###           3 Q872   
### 
### fe-1 with SUC2::AtFE
### line_number T2_line T3_line
###           1 Q718          
###           2 Q719    Q928   
###           3 Q858          
###           4 Q859          
###           5 Q860          
### 
### fe-1 with SUC2::MtFE
### line_number T2_line T3_line
###           1 Q720      
###           2 Q721          
###           3 Q766          
###           4 Q767          
###           5 Q768    Q929   
###           6 Q769    Q930   
###           7 Q770          
###           8 Q771    Q931   
###           9 Q861          
###           10 Q862                 
### 
### Ler-0 with SUC2::AtFE
### line_number T2_line T3_line 
###           1 Q863    Q932   
###           2 Q864    Q933   
###           3 Q865    Q934   
### 
### Ler-0 with SUC2::MtFE
### line_number T2_line T3_line
###           1 Q866    Q935   
###           2 Q867          
###           3 Q868    Q936   
###           4 Q869          
###           5 Q870    Q937   
###           6 Q871
### 
###########################################################
T2_lines <- paste0("Q", c(718:723, 766:773, 858:872, 874))
T3_lines <- paste0("Q", c(785:787, 928:939))

# T2 graphs
Atsubplot <- function(df2, plt){
  plt_title <- paste0(df2$genotype, ' - ', df2$line_number)
  plt + geom_jitter(data = filter(df2, mutant == 'Insert'),
                    aes(days_to_flower, total_leaves),
                    size = 1.5, colour = g_colours[9]) +
    ggtitle(plt_title) +
    theme(legend.position = 'none', 
          plot.title = element_text(size = 10),
          axis.text = element_text(size = 10),
          axis.title.x = element_text(size = 12),
          axis.title.y = element_text(size = 12)) +
    labs(x = "Days to flower", y = 'Total leaves') 
}

Atplot <- function(df){
  plt <- df %>% 
    filter(genotype %in% c('Ler-0', 'fe-1')) %>% 
    mutate(ref_geno = genotype) %>% 
    ggplot(aes(days_to_flower, total_leaves, fill = genotype)) +
    stat_ellipse(geom = "polygon", alpha = 0.6) +
    scale_fill_manual(values = g_colours[c(3,2,2,6,7)])
  
  df %>% 
    filter(mutant == 'Insert') %>% 
    split(.$sowing_number) %>% 
    imap(~Atsubplot(.x, plt))
}

At_FTdata_T2 <- At_FTdata %>% 
  filter(sowing_number %in% T2_lines) %>% 
  mutate(set = case_when(sowing_date == "1/12/17" ~ 1,
                         sowing_date == "08/01/18" ~ 2,
                         sowing_date == "13/03/18" ~ 3)) %>% 
  group_by(genotype) %>%
  mutate(line_number = str_extract(comments, '[^;]*'))

batch1 <- At_FTdata_T2 %>% 
  filter(set == 1) %>% 
  Atplot()

batch2 <- At_FTdata_T2 %>% 
  filter(set == 2) %>% 
  Atplot()

batch3 <- At_FTdata_T2 %>% 
  filter(set == 3) %>% 
  Atplot()

ggarrange(batch1$Q718, batch1$Q719, batch3$Q858, batch3$Q859, batch3$Q860,
          
          batch1$Q720, batch1$Q721, batch2$Q766, batch2$Q767, batch2$Q768,
          batch2$Q769, batch2$Q770, batch2$Q771, batch3$Q861, batch3$Q862,
          ncol = 3, nrow = 5)

# ggsave("Ch5_Athal_T2_A.png", height = 297, width = 210, units = "mm")

ggarrange(batch3$Q863, batch3$Q864, batch3$Q865,
          
          batch3$Q866, batch3$Q867, batch3$Q868, batch3$Q869, batch3$Q870,
          batch3$Q871,
          ncol = 3, nrow = 3)

# ggsave("Ch5_Athal_T2_B.png", height = 178.2, width = 210, units = "mm")

# T3 graphs
AT_T3_days <- At_FTdata %>% 
  filter(sowing_number %in% T3_lines) %>% 
  filter(mutant != 'No_Insert') %>% 
  mutate(line_number  = case_when(sowing_number %in% c("Q786","Q787", "Q938","Q939") ~ ' ',
                              TRUE ~ str_extract(comments, '[^;]*'))) %>% 
  group_by(genotype, sowing_number, line_number) %>% 
  summarise(average_days = mean(days_to_flower, na.rm = T),
            average_leaves = mean(total_leaves, na.rm = T),
            
            moe_days = gthor::moe(days_to_flower),
            moe_leaves = gthor::moe(total_leaves)
  ) %>% 
  arrange(genotype, desc(average_days)) %>% 
  ungroup() %>% 
  mutate(sowing_number = fct_inorder(sowing_number),
         sowing_number = fct_relevel(sowing_number, "Q786", "Q938")) %>% 
  ggplot(aes(sowing_number, average_days, 
             fill = genotype, label = str_extract(line_number, '#(.*)'))) +
  geom_col() +
  annotate("rect", xmin = Inf, xmax = 0, ymin = 18.1, ymax = 25.59, alpha = .2) +
  geom_col() +
  geom_errorbar(aes(ymin = average_days - moe_days, 
                    ymax =  average_days + moe_days), width = 0.5) +
  geom_text(aes(y = 10), size = 5, colour = "white") +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 30)) +
  scale_fill_manual(values = g_colours[c(3, 10, 9, 8, 4, 5)],
                    breaks=c("Ler-0","fe-1","fe-1 with SUC2::AtFE","fe-1 with SUC2::MtFE","Ler-0 with SUC2::AtFE",
                             "Ler-0 with SUC2::MtFE")) +
  theme(axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) +
  labs(x = "Individual Lines", y = 'Mean days to flowering')

AT_T3_leaves <- At_FTdata %>% 
  filter(sowing_number %in% T3_lines) %>% 
  filter(mutant != 'No_Insert') %>% 
  mutate(line_number  = case_when(sowing_number %in% c("Q786","Q787", "Q938","Q939") ~ ' ',
                                  TRUE ~ str_extract(comments, '[^;]*'))) %>% 
  group_by(genotype, sowing_number, line_number) %>% 
  summarise(average_days = mean(days_to_flower, na.rm = T),
            average_leaves = mean(total_leaves, na.rm = T),
            
            moe_days = gthor::moe(days_to_flower),
            moe_leaves = gthor::moe(total_leaves)
  ) %>% 
  arrange(genotype, desc(average_leaves)) %>% 
  ungroup() %>% 
  mutate(sowing_number = fct_inorder(sowing_number),
         sowing_number = fct_relevel(sowing_number, "Q786", "Q938")) %>% 
  ggplot(aes(sowing_number, average_leaves, 
             fill = genotype, label = str_extract(line_number, '#(.*)'))) +
  geom_col() +
  annotate("rect", xmin = Inf, xmax = 0, ymin = 8.9, ymax = 19.7, alpha = .2) +
  geom_col() +
  geom_errorbar(aes(ymin = average_leaves - moe_leaves, 
                    ymax =  average_leaves + moe_leaves), width = 0.5) +
  geom_text(aes(y = 5), size = 5, colour = "white") +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 30)) +
  scale_fill_manual(values = g_colours[c(3, 10, 9, 8, 4, 5)],
                    breaks=c("Ler-0","fe-1","fe-1 with SUC2::AtFE","fe-1 with SUC2::MtFE","Ler-0 with SUC2::AtFE",
                             "Ler-0 with SUC2::MtFE")) +
  theme(axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) +
  labs(x = "Individual Lines", y = 'Mean leaves at flowering')

ggarrange(AT_T3_days, AT_T3_leaves, nrow = 2, common.legend = T, legend = 'right', labels = c("A", "B"))

# ggsave("Ch5_At_complementation.png", width = 227, height = 181, units = 'mm')

# T3 flowering summary
At_FTdata %>% 
  filter(sowing_number %in% T3_lines) %>% 
  filter(mutant != 'No_Insert') %>% 
  mutate(line_number  = case_when(sowing_number %in% c("Q786","Q787", "Q938","Q939") ~ ' ',
                                  TRUE ~ str_extract(comments, '[^;]*'))) %>% 
  group_by(genotype, sowing_number, line_number) %>% 
  summarise(average_days = mean(days_to_flower, na.rm = T),
            average_leaves = mean(total_leaves, na.rm = T),
            
            moe_days = gthor::moe(days_to_flower),
            moe_leaves = gthor::moe(total_leaves)
  ) %>% 
  arrange(genotype, desc(average_days)) %>% 
  ungroup() %>% 
  mutate(sowing_number = fct_inorder(sowing_number),
         sowing_number = fct_relevel(sowing_number, "Q786", "Q938"))  %>% 
  
  filter(grepl('Ler-0 ', genotype)) %>% # note the space!
  mutate(late_days = (average_days-16.5)/16.5*100,
         diff_days = average_days-16.5,
         late_leaves = (average_leaves-8.74)/8.74*100,
         diff_leaves = average_leaves-8.74) %>% 
  group_by(genotype)

# fe-1 Q787 stats
27.2/17.7*100 # 154%
20.8/8.74*100 # 237%

# fe-1 Q939 stats
26.1/16.5*100 # 158%
22.2/7.96*100 # 279%

###########################################################
### MtFE gene expression
###
### 12 day old cotyledon and root samples (ZT2) 
### NF18291           Q740
### NF5076            Q742
### Wild type (R108)  Q743
###
### Tissue data was done using cDNA generated by 
### Mau Jaudal
###
### NF5076            Q742    14 days
### Wild type (R108)  Q743    14 days
### NF5076            Q635    28 days
### Wild type (R108)  Q636    28 days
### NF5076            Q228_2  61 days
### NF5076 WT Seg     Q228_11 61 days
###########################################################

# Expression up and downstream of the insertions
FE_up_down <- gene_expr %>% 
  filter(date == "31/01/18") 

FE_positions <- c("MtFE_down", "MtFE_up")

FE_up_down_res <- list()

for(i in 1:2){
  FE_up_down_res[[i]] <- FE_up_down %>% 
    filter(target %in% c(FE_positions[[i]], "MtPP2A")) %>% 
    rt_summary() %>% 
    rt_test() 
}

names(FE_up_down_res) <- FE_positions

FE_up_down_res %>% 
  list_to_df() %>% 
  mutate(genotype = if_else(genotype == "R108", 'Wild-type \n (R108)', genotype)) %>% 
  ggplot(aes(fct_rev(genotype), mean_expr, fill = genotype)) +
  geom_bar(stat = "identity") +
  facet_grid(.~ fct_rev(name)) +
  scale_y_continuous(expand=c(0,0), limits = c(0, 1)) +
  scale_fill_manual(values =  g_colours[c(3,3,8)]) +
  labs(y = expression("Expression relative to"~italic("PP2A"))) +
  theme(legend.position = "none",
        axis.title.x = element_blank())

# Expression up and downstream of the insertions table
E1_up_down_res_tbl <- list()

for(i in 1:2){
  E1_up_down_res_tbl[[i]] <- E1_up_down %>% 
    filter(target %in% c(FE_positions[[i]], "MtPP2A")) %>% 
    rt_calc()
}

bind_rows(FE_up_down_res_tbl)

# Tissue
tissues <- structure(list(sample = c("Ape_12", "Ape_27", "Bud_86", "Cot_5", 
                                     "Flo_86", "LDLea_12", "LDLea_27", "Mon_12", 
                                     "Roo_12", "Roo_5", "SDLea", "Ste_40"), 
                          tissue = c("Apex (12 days)", "Apex (27 days)", "Buds (86 days)", 
                                     "Cotyledon\n(5 days)", "Flowers (86 days)", "Leaves (LD)\n(12 days)", 
                                     "Leaves (LD)\n(27 days)", "Monofoliate\n(12 days)", "Root (12 days)", 
                                     "Root (5 days)", "Leaf (SD)", "Stem (40 days)")), 
                     .Names = c("sample", "tissue"), 
                     row.names = c(NA, -12L), 
                     class = c("tbl_df", "tbl", "data.frame"))

# Tissues

FE_tissues <- gene_expr %>% 
  filter(date == '23/07/18', target %in% c("MtFE", "MtPP2A")) %>% 
  rt_summary() %>% 
  rt_test() %>% 
  left_join(tissues) %>%
  mutate(tissue = factor(tissue, levels = tissue[c(10,9,4,8,6,7,11,12,1,2,3,5)])) %>% 
  
  ggplot(aes(tissue, mean_expr, fill = tissue)) +
  geom_col(fill = g_colours[8]) +
  geom_errorbar(aes(ymin = mean_expr - se, ymax = mean_expr + se), width = 0.25) +
  scale_y_continuous(expand = c(0,0), limits = c(0, 1)) +
  labs(y = expression("Expression relative to"~italic("PP2A"))) +
  theme(legend.position = 'none',
        axis.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, angle = 45, hjust = 1),
        axis.title.x = element_blank()) +
  ggtitle(expression(italic("MtFE")))

# Tissues table
gene_expr %>% 
  filter(date == '23/07/18', target %in% c("MtFE", "MtPP2A")) %>% 
  left_join(tissues) %>%
  mutate(sample = tissue) %>% 
  separate(well, c("plate", "well")) %>% 
  select(-tissue, -plate) %>%
  rt_calc() 

# Genes in NF5076 Mtfe
FE_expr_plots <- list()

FE_expr_res <- gene_expr %>% 
  filter(date %in% c("29/03/17", "30/01/18", "26/10/18")) %>%
  rt_summary()

# MtFE
FE_expr_plots[[1]] <- gene_expr %>% 
  filter(date == '06/12/16', target %in% c("MtFE", "MtPP2A")) %>% 
  rt_summary() %>% 
  rt_test() %>% 
  mutate(genotype = case_when(genotype == "NF5076_FE_WTSeg" ~ "Wild-type\n(NF5076)",
                              genotype == "NF5076_FE_Homo" ~ "NF5076\nHomozygote"),
         genotype = factor(genotype, levels = c("Wild-type\n(NF5076)","NF5076\nHomozygote")),
         days = '61 days') %>% 
  ggplot(aes(genotype, mean_expr, fill = genotype)) +
  geom_col() +
  geom_errorbar(aes(ymin = mean_expr - se, ymax = mean_expr + se), width = 0.25) +
  scale_fill_manual(values = g_colours[c(8,3)]) +
  scale_y_continuous(expand = c(0,0), limits = c(0, 1)) +
  # labs(y = expression("Expression relative to"~italic("PP2A"))) +
  theme(legend.position = 'none',
        strip.placement = 'outside',
        strip.text = element_text(size = 18),
        axis.text.x = element_blank(),
        axis.text.y = element_text(size = 14),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.x = element_blank()) +
  ggtitle(expression(italic("MtFE"))) +
  facet_grid(. ~ days, switch = "x") 

# All the others
FE_expr_GoI <- c(NA, "MtFTa1", "MtFTa2", "MtFTb1", "MtFTb2", "MtFTIP1a", "MtNaKR1b")
for(i in 2:7){
  
  FE_expr_plots[[i]] <- FE_expr_res %>% 
    filter(target %in% c(FE_expr_GoI[i], "MtPP2A")) %>%
    rt_test() %>%
    left_join(FE_expr_daydf) %>%
    mutate(genotype = case_when(genotype == "NF5076_fe_homo" ~ "NF5076 homozygote",
                                genotype == "NF5076_WT_Seg" ~ "NF5076 Wild-type segragant",
                                genotype == "Wild_type_R108" ~ "Wild-type (R108)"),
           genotype = factor(genotype, levels = c("Wild-type (R108)", "NF5076 Wild-type segragant", "NF5076 homozygote") )) %>%
    
    ggplot(aes(genotype, mean_expr, fill = genotype)) +
    geom_col() +
    geom_errorbar(aes(ymin = mean_expr - se,
                      ymax = mean_expr + se),
                  width = 0.2) +
    facet_grid(. ~ days, scales = "free_x", switch = "x") +
    scale_y_continuous(expand=c(0,0), limits = c(0, 1)) +
    scale_fill_manual(values =  g_colours[c(8, 8, 3)]) +
    # labs(y = "Expression relative to PP2A") +
    theme(strip.placement = 'outside',
          strip.text = element_text(size = 14),
          panel.spacing = unit(0, "lines"),
          axis.title.x = element_blank(),
          axis.title.y = element_blank(),
          axis.text.x = element_blank(),
          axis.text.y = element_text(size = 14),
          axis.ticks.x = element_blank(),
          legend.position = "none",
          plot.title = element_text(size = 14, face = "bold"),
          legend.text=element_text(size=14))
  
}

FE_expr_plots[[2]] <- FE_expr_plots[[2]] +
  ggtitle(expression(italic('MtFTa1')))

FE_expr_plots[[3]] <- FE_expr_plots[[3]] +
  ggtitle(expression(italic('MtFTa2')))

FE_expr_plots[[4]] <- FE_expr_plots[[4]] +
  ggtitle(expression(italic('MtFTb1')))

FE_expr_plots[[5]] <- FE_expr_plots[[5]] +
  ggtitle(expression(italic('MtFTb2')))

FE_expr_plots[[6]] <- FE_expr_plots[[6]] +
  ggtitle(expression(italic('FTIP1-like ')*'('*italic('Medtr0291s0010')*')'))

FE_expr_plots[[7]] <- FE_expr_plots[[7]] +
  ggtitle(expression(italic('NaKR1-like ')*'('*italic('Medtr7g100450')*')'))

ggarrange(FE_tissues,
          ggarrange(FE_expr_plots[[1]], FE_expr_plots[[2]], FE_expr_plots[[3]], FE_expr_plots[[4]], 
                    FE_expr_plots[[5]], FE_expr_plots[[6]], FE_expr_plots[[7]],
                    nrow = 2, ncol = 4),
          nrow = 2, heights = c(1.2,2), labels = c("A", "B"), font.label = list(size = 28))

# ggsave("Ch5_FE_expression.png", width = 400, height = 300, units = "mm")

# Summary tables
FE_expr_summ <- list()

FE_expr_summ[[1]] <- gene_expr %>% 
  filter(date == '06/12/16', target %in% c("MtFE", "MtPP2A")) %>% 
  rt_calc()

for(i in 2:6){
  
  FE_expr_summ[[i]] <- temp_gene_expr2 %>% 
    filter(date %in% c("29/03/17", "30/01/18", "26/10/18"),
           target %in% c(FE_expr_GoI[i], "MtPP2A")) %>% 
    mutate(genotype = case_when(genotype == "NF5076_fe_homo" ~ "NF5076 homozygote",
                                genotype == "NF5076_WT_Seg" ~ "NF5076 Wild-type segragant",
                                genotype == "Wild_type_R108" ~ "Wild-type (R108)")) %>% 
    rt_calc() 
}

###########################################################
### NF-Y-like gene trees
###########################################################

# NF-YA
NFYA_phylo <- ggtree(NFYA_tree, branch.length="none", size=1.25) + 
  geom_tiplab(size = 5, offset = .5) + xlim(0, 12) +
  geom_tippoint(alpha=1, colour = g_colours[2], size=3) +
  geom_nodelab(geom = "label")

# NF-YB
NFYB_phylo <- ggtree(NFYB_tree, branch.length="none", size=1.25) +  
  xlim(0, 13) +
  geom_tippoint(alpha=1, colour = g_colours[2], size=3) +
  geom_nodelab(geom = "label") +
  geom_tiplab(size = 5, offset = .5, colour = c(rep('black', 12), 
                                                rep(g_colours[4], 4), 
                                                rep('black', 14))) 

# NF_YC
NFYC_phylo <- ggtree(NFYC_tree, branch.length="none", size=1.25) +  
  xlim(0, 13) +
  geom_nodelab(geom = "label") +
  geom_tippoint(alpha=1, colour = g_colours[2], size=3) +
  geom_tiplab(size = 5, offset = .5, colour = c(rep(g_colours[4], 4),
                                                'black', 
                                                rep(g_colours[4], 2),
                                                rep('black', 10)))

ggarrange(NFYA_phylo, NFYB_phylo, NFYC_phylo, ncol = 3)

# ggsave("Ch5_NF-Y_trees.png", width = 423, height = 181, units = 'mm')

###########################################################
### Y2H scoring
###########################################################

# Clean up data to remove those that didn't grow on the positive control media
Y2H_scor_clean <- Y2H_scor %>%
  left_join(Y2H_scor%>%
              filter(Media=="SD-LW") %>%
              select(Experiment, BD, AD, Replicate, `3 days`, `6 days`) %>%
              filter((`3 days` == 0) | (`3 days` == 1 & `6 days` == 1) | (`6 days` == 1)) %>%
              select(Experiment, BD, AD, Replicate) %>%
              mutate(pos_cntrl = F)
  ) %>% 
  mutate(`3 days` = ifelse(!is.na(pos_cntrl), NA_integer_, `3 days`),
         `6 days` = ifelse(!is.na(pos_cntrl), NA_integer_, `6 days`),
         `10 days` = ifelse(!is.na(pos_cntrl), NA_integer_, `10 days`)) %>%
  select(-pos_cntrl)
 
# Y2H graph - 10 days and 10mM 3AT
graph_data <- Y2H_scor_clean %>% 
  filter(`3AT` == 10) %>%
  select(BD, AD, Replicate, int = `10 days`) %>% 
  # There is a BD:MtNF-YB-1/AD:MtNF-YC-3 interaction which is really weak on SD-LW 
  # so I eliminate it in favour of my Experiment9 repeats which grew much better on SD_LW.
  # There is an additional single BD:MtNF-YC-1/AD:MtNF-YB-1 reaction that was ok on SD-LW 
  # but did not grow on SD_LWH while the repeats did so I removed that too. 
  slice(-c(206, 295)) %>% 
  filter(!is.na(int),
         !BD %in% c("Empty", "POS", "NEG"),
         !AD %in% c("Empty", "POS", "NEG"),
         BD != "AT5G15840") %>% # Remove CO as there is autoactivation
  arrange(BD, AD, Replicate) 

# Table of interactions
graph_res <- graph_data %>% 
  group_by(BD, AD) %>% 
  summarise(m_int = mean(int)) %>% 
  filter(m_int >= 2) %>% # Total of 22/56 interactions
  select(-m_int)

# Which interactions are uni-/bi-directional
recursive_IND <-
  1:nrow(graph_res) %>% 
  sapply(function(x){
    if(any((as.character(graph_res[x,]) == t(graph_res[,c(2,1)])) %>% {.[1,] & .[2,]}))
      return(T) else return(F)
  })

unidir <- graph_res[!recursive_IND,] %>% 
  mutate(status = 'U',
         weight = 1)

bidir <- graph_res[recursive_IND,][!(graph_res[recursive_IND,] %>% apply(1,sort) %>% t %>% duplicated(.)),] %>% 
  mutate(status = "B",
         weight = 2)

graph_res_dir <- graph_res %>% 
  left_join(bind_rows(unidir, bidir))

nodes <- Y2H_scor_clean %>% 
  filter(!is.na(BD),
         !BD %in% c("Empty", "POS", "NEG")) %>% 
  select(node = BD) %>%
  arrange(node) %>% 
  distinct()

# Y2H graph
Y2H_graph <- tbl_graph(nodes = nodes, edges = graph_res_dir, directed = T) %>% 
  ggraph(layout = 'linear', circular = TRUE) + 
  geom_edge_link(aes(colour = status, width = weight),
                 arrow = arrow(length = unit(4, 'mm')),
                 start_cap = circle(3, 'mm'),
                 end_cap = circle(3, 'mm')) + 
  geom_node_point(size = 4, colour = g_colours[8]) + 
  coord_fixed() +
  geom_node_text(aes(label = node), repel = T) +
  scale_edge_width(range = c(0.8, 1.2)) + 
  scale_edge_colour_manual(values = g_colours[c(9, 10)]) +
  theme_graph() +
  theme(legend.position = 'none')


ggarrange(NULL, Y2H_graph, ncol = 2, labels = c("A", "B"))
# ggsave("Ch5_Y2H_graph.png", height = 120, width = 313, units = 'mm')

# Day 10 results
Y2H_names <- data_frame(BD = c('Medtr6g444980', 'AT5G15840', 
                               'AT5G47640', 'Medtr3g058980', 
                               'Medtr5g095740', 'Medtr1g082660', 
                               'Medtr3g099180', 'Medtr7g113680'),
                      name = c('Medtr6g444980 (MtFE)', 'AT5G15840 (CO)', 
                               'AT5G47640 (AtNF-YB2)', 'Medtr3g058980 (NF-YB-like)',
                               'Medtr5g095740 (NF-YB-like)', 'Medtr1g082660 (NF-YC-like)', 
                               'Medtr3g099180 (NF-YC-like)', 'Medtr7g113680 (NF-YC-like)'))

Y2H_results_graph <- function(x, y){
  ggplot(x, aes(AD, BD, fill = meanGrowth)) +
    geom_tile(colour = "white")  +
    theme(axis.text.y = element_blank(),
          axis.text.x = element_text(angle = 45, margin = margin(t=40, r = 60)),
          axis.title.x = element_blank(),
          axis.title.y = element_blank(),
          axis.line = element_blank(),
          axis.ticks.x = element_blank(),
          axis.ticks.y = element_blank()) +
    facet_grid(`3AT`~.)  +
    coord_equal() +
    scale_fill_continuous(low=g_colours[9], high=g_colours[3], na.value = '#d7d7d7') +
    ggtitle(y)
}

Y2H_results <- Y2H_scor_clean %>%
  # Eliminate failed colonies leaving repeats
  left_join(Y2H_scor_clean %>% 
              filter(Experiment == 'Experiment9',
                     !BD %in% c("POS", "NEG")) %>% 
              select(BD, AD) %>% 
              unique() %>% 
              mutate(repeat_growth = T)) %>% 
  filter(is.na(repeat_growth) | Experiment == "Experiment9",
         Media != "SD-LW") %>% 
  select(`3AT`,BD, AD, Replicate, int = `10 days`) %>%
  filter(
    !BD %in% c("Empty", "POS", "NEG")) %>% 
  group_by(`3AT`, BD, AD) %>%
  summarise(meanGrowth=mean(int, na.rm = T)) %>% 
  mutate(AD = factor(AD, levels = c("Empty", "AT5G15840", "AT5G47640", "Medtr6g444980", 
                                    "Medtr3g058980", "Medtr5g095740", "Medtr1g082660", 
                                    "Medtr3g099180", "Medtr7g113680"))) %>% 
  left_join(Y2H_names) %>% 
  split(.$name) %>% 
  imap(~Y2H_results_graph(.x, .y))

ggpubr::ggarrange(Y2H_results[[7]], Y2H_results[[1]],
                  Y2H_results[[2]], Y2H_results[[4]],
                  Y2H_results[[6]], Y2H_results[[3]],
                  Y2H_results[[5]], Y2H_results[[8]],
                  ncol = 4, nrow = 2, common.legend = T)

# ggsave("Ch5_Y2H_10D_10_3AT.png", width = 445, height = 244, units = 'mm')

# Known controls
Y2H_controls_graph <- function(x, y){
  ggplot(x, aes(fct_rev(AD), 1, fill = meanGrowth)) +
    geom_tile(colour = "white") +
    facet_grid(`3AT`~ Media)  +
    coord_equal() +
    scale_fill_continuous(low=g_colours[9], high=g_colours[3], na.value = '#d7d7d7') +
    theme(legend.position = "bottom",
          axis.text.x = element_text(angle = 45, margin = margin(t=40, r = 60)),
          axis.text.y = element_blank(),
          axis.title.x = element_blank(),
          axis.title.y = element_blank(),
          axis.line = element_blank(),
          axis.ticks.x = element_blank(),
          axis.ticks.y = element_blank(),
          panel.grid.major = element_blank(),
          panel.grid.minor = element_blank()) +
    ggtitle(y)
}

Y2H_controls <- Y2H_scor_clean %>%
  group_by(Experiment, Media, `3AT`, BD, AD) %>% 
  summarise(meanGrowth=mean(`10 days`, na.rm = T)) %>% 
  ungroup() %>% 
  filter(BD %in% c("POS", "NEG")) %>% 
  split(.$Experiment) %>% 
  imap(~Y2H_controls_graph(.x, .y))

Y2H_controls[[1]]

ggpubr::ggarrange(Y2H_controls[[1]], Y2H_controls[[2]], Y2H_controls[[3]], 
                  Y2H_controls[[4]], Y2H_controls[[5]], Y2H_controls[[6]], 
                  Y2H_controls[[7]], Y2H_controls[[8]], Y2H_controls[[9]],
                  ncol = 3, nrow = 3, common.legend = T, legend = "bottom")

# ggsave("Ch5_Y2H_known_controls.png", height = 445, width = 244, units = 'mm')

# Negative controls
Y2H_neg_controls_graph <- function(x, y){
  ggplot(x, aes(AD, BD, fill = meanGrowth)) +
    geom_tile(colour = "white")  +
    theme(axis.text.y = element_blank(),
          axis.text.x = element_text(angle = 45, margin = margin(t=40, r = 60)),
          axis.title.x = element_blank(),
          axis.title.y = element_blank(),
          axis.line = element_blank(),
          axis.ticks.x = element_blank(),
          axis.ticks.y = element_blank()) +
    facet_grid(`3AT`~.)  +
    coord_equal() +
    scale_fill_continuous(low=g_colours[9], high=g_colours[3], na.value = '#d7d7d7',  limits=c(0, 3)) +
    ggtitle(y)
}

Y2H_neg_controls <- Y2H_scor_clean %>%
  group_by(Experiment, Media, `3AT`, BD, AD) %>% 
  summarise(meanGrowth=mean(`10 days`, na.rm = T)) %>% 
  ungroup() %>% 
  filter(BD == "Empty",
         Media == "SD-LWH") %>% 
  mutate(AD = factor(AD, levels = c("Empty", "AT5G15840", "AT5G47640", "Medtr6g444980", 
                                    "Medtr3g058980", "Medtr5g095740", "Medtr1g082660", 
                                    "Medtr3g099180", "Medtr7g113680"))) %>% 
  left_join(Y2H_scor_clean %>% 
              filter(Position == 'A1', Media == "SD-LW") %>% 
              left_join(filter((Y2H_names))) %>% 
              select(Experiment, name)) %>% 
  split(.$name) 

Y2H_neg_plots <- list()

for(i in 1:8){
  Y2H_neg_plots[[i]] <- Y2H_neg_controls_graph(Y2H_neg_controls[[i]], pull(Y2H_neg_controls[[i]][1,7]))
}

ggpubr::ggarrange(Y2H_neg_plots[[1]], Y2H_neg_plots[[2]],
                  Y2H_neg_plots[[3]], Y2H_neg_plots[[4]],
                  Y2H_neg_plots[[5]], Y2H_neg_plots[[6]],
                  Y2H_neg_plots[[7]], Y2H_neg_plots[[8]],
                  ncol = 4, nrow = 2, common.legend = T, legend = "bottom")

# ggsave("Ch5_Y2H_neg_controls.png", width = 445, height = 244, units = 'mm')
