###########################################################
### Ch4 - Script 4 - MtFTIP1 - Medtr0291s0010
###########################################################

###########################################################
### Theme
###########################################################
theme_set(my_theme())

###########################################################
### FTIP1-like gene tree
###########################################################
# Full tree
full_tree <- ggtree(FTIP1_tree, layout="circular", branch.length="none", size=1.25) + 
  geom_hilight(node=100, fill = g_colours[3], alpha=.4) + 
  geom_tippoint(alpha=1, colour = g_colours[2], size=3) 

rotate_tree(full_tree, 180)

# Subtree
# Bootstrap labels
labs <- as.character(1:147)
labs[27:42] <- NA
labs[100:114] <-  as.character(c(99.7, 97.8, 99.7, 64.6,
                                 99.5, 100, 63.3, 100, 
                                 100, 96.8, 64.7, 100, 
                                 100, 100, 97.3))

rec_tree <- ggplot(FTIP1_tree, aes(x, y)) + 
  geom_tree(size=1) + 
  theme_tree() 

viewClade(rec_tree, node=100) + 
  geom_tiplab(size = 5, offset = 0.01, 
              colour = c(rep('black', 37), 
                         rep(g_colours[4], 2), 
                         rep('black', 38))) + 
  geom_label(aes(label=labs), size = 4, label.padding = unit(0.15, "lines")) +
  geom_tippoint(color=g_colours[2], size=2)

###########################################################
### Flowering time 
###
###             NF_line      Wild-type (R108)
### NF3680      
###      VLD    Q040         Q042
###
### NF10483
###      LD     Q277         Q280
###      SD     Q426         Q429
###      VLD    Q041         Q042
###      VSD    Q278         Q281
###########################################################
# NF3680
NF3680_flowering <- FTdata %>% 
  filter(sowing_number %in% c("Q040", "Q042")) %>% 
  ggplot(aes(days_to_flower, node_num, colour = fct_rev(mutant))) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(10, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 30)) + 
  scale_y_continuous(expand = c(0, 0), limits = c(0, 10)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position="none",
        legend.text = element_text(size = 16),
        axis.title.x = element_text(vjust = -2)) +
  ggtitle('NF3680')

# NF10483
NF10483_flowering_top <- FTdata %>% 
  filter(sowing_number %in% c("Q277", "Q280",
                              "Q426", "Q429")) %>%
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  facet_grid( ~ conditions) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 85)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 20)) +
  labs(x = "", y = "Nodes at flowering") +
  theme(legend.position="none",
        axis.title.x = element_blank(),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines")) + 
  ggtitle('NF10483')

NF10483_flowering_bottom <- FTdata %>% 
  filter(sowing_number %in% c("Q041", "Q042",
                              "Q278", "Q281")) %>% 
  mutate(mutant = if_else(mutant == 'Wild-type', "Wild-type (R108)", mutant),
         mutant = fct_relevel(mutant, "Homozygote", "Heterozygote", 
                              "Wild-type segregant")) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 9, 1, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  facet_grid( ~ conditions) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 85)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 20)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(.12, 2.25),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        axis.title.x = element_text(vjust = -2))

###########################################################
### NF10483 gene expression
###
### NF10483           Q041
### Wild-type (R108)  Q042
###########################################################

labels <- c("Q041_plant_7" = "NF10483 \nplant #7",
            "Q042" = 'Wild-type')

gene_expr %>% 
  filter(date == '18/07/16', 
         target %in% c('MtFTIP1', 'MtPP2A'),
         grepl('Q04', sample)) %>% 
  rt_summary() %>% 
  rt_test() %>%
  
  ggplot(aes(fct_reorder(sample, mean_expr, .desc = T), mean_expr, fill = genotype)) +
  geom_col() +
  geom_errorbar(aes(ymin = mean_expr - se, ymax =  mean_expr + se), width = 0.2) +
  scale_y_continuous(expand = c(0,0), limits = c(0,1)) +
  scale_x_discrete(labels = labels) +
  theme(axis.title.x = element_blank(), 
        legend.position= "none") +
  scale_fill_manual(values = g_colours[c(3, 8)]) +
  labs(y = expression("Expression relative to"~italic("PP2A")))

# FTIP1 table
gene_expr %>% 
  filter(date == '18/07/16', 
         target %in% c('MtFTIP1', 'MtPP2A'),
         grepl('Q04', sample)) %>% 
  rt_calc()

# Significance
gene_expr %>% 
  filter(date == '18/07/16', 
         target %in% c('MtFTIP1', 'MtPP2A'),
         grepl('Q04', sample)) %>% 
  rt_summary() %>% 
  rt_test() %>% 
  mutate(data = map(data, ~ select(.x, bio_replicate, comp_exp))) %>% 
  unnest(data) %$%
  t.test(comp_exp ~ sample)

  
###########################################################
### NF10483 gene linkage
###
### NF10483           Q491
### Wild-type (R108)  Q493
###########################################################

NF10483_linkage <- FTdata %>% 
  filter(sowing_number %in% c("Q491", "Q493")) %>% 
  mutate(mutant = fct_relevel(mutant, "Homozygote", "Heterozygote", 
                              "Wild-type segregant")) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 9, 1, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 85)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 20)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position="none",
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        axis.title.x = element_text(vjust = -2)) +
  ggtitle('NF10483 - VSD')

ggpubr::ggarrange(NF10483_flowering_top, NF10483_flowering_bottom, 
                  ggarrange(NF3680_flowering, NF10483_linkage, 
                            ncol=2, labels = c("B", "C"),
                            font.label = list(size = 20)), 
                  nrow = 3, labels=c("A", "", ""), font.label = list(size = 20))

# ggsave("Ch5_FTIP1_flowering.pdf", width = 280, height = 300, units = "mm")
